DOCv1 = """	РАЗДЕЛ А СЕЛЬСКОЕ ХОЗЯЙСТВО, ОХОТА И ЛЕСНОЕ ХОЗЯЙСТВО
	Подраздел АА СЕЛЬСКОЕ ХОЗЯЙСТВО, ОХОТА И ЛЕСНОЕ ХОЗЯЙСТВО
01	Сельское хозяйство, охота и предоставление услуг в этих областях
01.1	Растениеводство
01.11	Выращивание зерновых, технических и прочих сельскохозяйственных  культур, не включенных в другие группировки
01.11.1	Выращивание зерновых и зернобобовых культур
01.11.2	Выращивание картофеля, столовых корнеплодных и клубнеплодных культур  с высоким содержанием крахмала или инулина
01.11.3	Выращивание масличных культур
01.11.4	Выращивание табака и махорки
01.11.5	Выращивание сахарной свеклы
01.11.6	Выращивание кормовых культур; заготовка растительных кормов
01.11.7	Выращивание прядильных культур
01.11.8	Выращивание прочих сельскохозяйственных культур, не включенных в  другие группировки
01.12	Овощеводство; декоративное садоводство и производство продукции  питомников
01.12.1	Овощеводство
01.12.2	Декоративное садоводство и производство продукции питомников
01.12.3	Выращивание грибов, сбор лесных грибов и трюфелей
01.12.31	Выращивание грибов и грибницы (мицелия)
01.12.32	Сбор лесных грибов и трюфелей
01.13	Выращивание фруктов, орехов, культур для производства напитков и  пряностей
01.13.1	Выращивание винограда
01.13.2	Выращивание прочих фруктов и орехов
01.13.21	Выращивание плодовых и ягодных культур
01.13.22	Выращивание орехов
01.13.23	Выращивание посадочного материала плодовых насаждений
01.13.24	Сбор плодов, ягод и орехов, в том числе дикорастущих
01.13.3	Выращивание культур для производства напитков
01.13.4	Выращивание культур для производства пряностей
01.2	Животноводство
01.21	Разведение крупного рогатого скота
01.22	Разведение овец, коз, лошадей, ослов, мулов и лошаков
01.22.1	Разведение овец и коз
01.22.2	Разведение лошадей, ослов, мулов и лошаков
01.23	Разведение свиней
01.24	Разведение сельскохозяйственной птицы
01.25	Разведение прочих животных
01.25.1	Разведение пчел
01.25.2	Разведение кроликов и пушных зверей в условиях фермы
01.25.3	Разведение шелкопряда
01.25.4	Разведение оленей
01.25.5	Разведение верблюдов
01.25.6	Разведение домашних животных
01.25.7	Разведение лабораторных животных
01.25.8	Разведение водных пресмыкающихся и лягушек в водоемах, разведение  дождевых (калифорнийских) червей
01.25.81	Разведение водных пресмыкающихся и лягушек в водоемах
01.25.82	Разведение дождевых (калифорнийских) червей
01.25.9	Разведение прочих животных, не включенных в другие группировки
01.3	Растениеводство в сочетании с животноводством (смешанное сельское  хозяйство)
01.30	Растениеводство в сочетании с животноводством (смешанное сельское  хозяйство)
01.4	Предоставление услуг в области растениеводства, декоративного садоводства и животноводства, кроме ветеринарных услуг
01.41	Предоставление услуг в области растениеводства и декоративного садоводства
01.41.1	Предоставление услуг, связанных с производством сельскохозяйственных культур
01.41.2	Предоставление услуг по закладке, обработке и содержанию садов, парков и других зеленых насаждений
01.41.3	Предоставление услуг по эксплуатации мелиоративных систем
01.42	Предоставление услуг в области животноводства, кроме ветеринарных услуг
01.5	Охота и разведение диких животных, включая предоставление услуг в этих  областях
01.50	Охота и разведение диких животных, включая предоставление услуг в этих  областях
02	Лесное хозяйство, лесозаготовки и предоставление услуг в этих областях
02.0	Лесное хозяйство и предоставление услуг в этой области
02.01	Лесоводство и лесозаготовки
02.01.1	Лесозаготовки
02.01.2	Сбор дикорастущих и недревесных лесопродуктов
02.01.5	Лесоводство
02.01.6	Деятельность лесопитомников
02.01.61	Выращивание сеянцев, деревьев и кустарников
02.01.69	Выращивание прочей продукции питомников
02.02	Предоставление услуг в области лесоводства и лесозаготовок
02.02.1	Предоставление услуг в области лесоводства
02.02.2	Предоставление услуг в области лесозаготовок
	РАЗДЕЛ B РЫБОЛОВСТВО, РЫБОВОДСТВО
	Подраздел BА РЫБОЛОВСТВО, РЫБОВОДСТВО
05	Рыболовство, рыбоводство и предоставление услуг в этих областях
05.0	Рыболовство, рыбоводство и предоставление услуг в этих областях
05.01	Рыболовство
05.01.1	Рыболовство в открытых районах Мирового океана и внутренних морских водах
05.01.11	Вылов рыбы и водных биоресурсов в открытых районах Мирового океана и  внутренних морских водах сельскохозяйственными товаропроизводителями
05.01.12	Вылов рыбы и водных биоресурсов в открытых районах Мирового океана и  внутренних морских водах несельскохозяйственными товаропроизводителями
05.01.2	Рыболовство в реках, озерах, водохранилищах и прудах
05.01.21	Вылов рыбы и водных биоресурсов в реках, озерах, водохранилищах и  прудах сельскохозяйственными товаропроизводителями
05.01.22	Вылов рыбы и водных биоресурсов в реках, озерах, водохранилищах и  прудах несельскохозяйственными товаропроизводителями
05.01.3	Предоставление услуг в области рыболовства
05.02	Рыбоводство
05.02.1	Воспроизводство рыбы и водных биоресурсов
05.02.11	Воспроизводство рыбы и водных биоресурсов сельскохозяйственными  товаропроизводителями
05.02.12	Воспроизводство рыбы и водных биоресурсов несельскохозяйственными  товаропроизводителями
05.02.2	Предоставление услуг, связанных с воспроизводством рыбы и водных  биоресурсов
	РАЗДЕЛ С ДОБЫЧА ПОЛЕЗНЫХ ИСКОПАЕМЫХ
	Подраздел СА ДОБЫЧА ТОПЛИВНО-ЭНЕРГЕТИЧЕСКИХ ПОЛЕЗНЫХ  ИСКОПАЕМЫХ
10	Добыча каменного угля,бурого угля и торфа
10.1	Добыча, обогащение и агломерация каменного угля
10.10	Добыча, обогащение и агломерация каменного угля
10.10.1	Добыча каменного угля
10.10.11	Добыча каменного угля открытым способом
10.10.12	Добыча каменного угля подземным способом
10.10.2	Обогащение и агломерация каменного угля
10.10.21	Обогащение каменного угля
10.10.22	Агломерация каменного угля
10.2	Добыча, обогащение и агломерация бурого угля
10.20	Добыча, обогащение и агломерация бурого угля
10.20.1	Добыча бурого угля (лигнита)
10.20.11	Добыча бурого угля открытым способом
10.20.12	Добыча бурого угля подземным способом
10.20.2	Обогащение и агломерация бурого угля
10.20.21	Обогащение бурого угля
10.20.22	Агломерация бурого угля
10.3	Добыча и агломерация торфа
10.30	Добыча и агломерация торфа
10.30.1	Добыча торфа
10.30.2	Агломерация торфа
11	Добыча сырой нефти и природного газа; предоставление услуг в этих областях
11.1	Добыча сырой нефти и природного газа
11.10	Добыча сырой нефти и природного газа
11.10.1	Добыча сырой нефти и нефтяного (попутного) газа; извлечение фракций из  нефтяного (попутного) газа
11.10.11	Добыча сырой нефти
11.10.12	Добыча нефтяного (попутного) газа
11.10.13	Разделение и извлечение фракций из нефтяного (попутного) газа
11.10.14	Добыча горючих (битуминозных) сланцев, битуминозного песка и озокерита
11.10.2	Добыча природного газа и газового конденсата
11.10.21	Добыча природного газа
11.10.22	Добыча газового конденсата
11.10.3	Сжижение и регазификация природного газа для транспортирования
11.2	Предоставление услуг по добыче нефти и газа
11.20	Предоставление услуг по добыче нефти и газа
11.20.1	Предоставление услуг по бурению, связанному с добычей нефти, газа и  газового конденсата
11.20.2	Предоставление услуг по монтажу, ремонту и демонтажу буровых вышек
11.20.3	Предоставление услуг по доразведке месторождений нефти и газа на  особых экономических условиях (по соглашению о разделе продукции - СРП)
11.20.4	Предоставление прочих услуг, связанных с добычей нефти и газа
12	Добыча урановой и ториевой руд
12.0	Добыча урановой и ториевой руд
12.00	Добыча урановой и ториевой руд
12.00.1	Добыча и обогащение (сортировка) урановых руд
12.00.11	Добыча урановых руд подземным способом, включая способы подземного  и кучного выщелачивания
12.00.12	Добыча урановых руд открытым способом, включая способ кучного  выщелачивания
12.00.2	Добыча и обогащение ториевых руд
	Подраздел СВ ДОБЫЧА ПОЛЕЗНЫХ ИСКОПАЕМЫХ, КРОМЕ ТОПЛИВНО- ЭНЕРГЕТИЧЕСКИХ
13	Добыча металлических руд
13.1	Добыча и обогащение железных руд
13.10	Добыча и обогащение железных руд
13.10.1	Добыча железных руд подземным способом
13.10.2	Добыча железных руд открытым способом
13.10.3	Обогащение железных руд
13.2	Добыча и обогащение руд цветных металлов, кроме урановой и ториевой руд
13.20	Добыча и обогащение руд цветных металлов, кроме урановой и ториевой руд
13.20.1	Добыча и обогащение медной руды
13.20.2	Добыча и обогащение никелевой и кобальтовой руд
13.20.21	Добыча и обогащение никелевой руды
13.20.22	Добыча и обогащение кобальтовой руды
13.20.3	Добыча и обогащение алюминийсодержащего сырья (бокситов и нефелин- апатитовых руд)
13.20.31	Добыча алюминийсодержащего сырья подземным способом
13.20.32	Добыча алюминийсодержащего сырья открытым способом
13.20.33	Обогащение нефелин-апатитовых руд
13.20.4	Добыча руд и песков драгоценных металлов и руд редких металлов
13.20.41	Добыча руд и песков драгоценных металлов (золота, серебра и металлов  платиновой группы)
13.20.42	Добыча и обогащение руд редких металлов (циркония, тантала, ниобия и  др.)
13.20.5	Добыча и обогащение свинцово-цинковой руды
13.20.6	Добыча и обогащение оловянной руды
13.20.7	Добыча и обогащение титаномагниевого сырья
13.20.8	Добыча и обогащение вольфраммолибденовой руды
13.20.9	Добыча и обогащение руд прочих цветных металлов
13.20.91	Добыча и обогащение сурьмяно-ртутных руд
13.20.92	Добыча и обогащение руд марганцевых
13.20.93	Добыча и обогащение руд хромовых (хромитовых)
13.20.94	Добыча и обогащение руд прочих цветных металлов, не включенных в другие группировки
14	Добыча прочих полезных ископаемых
14.1	Разработка каменных карьеров
14.11	Добыча камня для памятников и строительства
14.12	Добыча известняка, гипсового камня и мела
14.13	Добыча сланцев
14.2	Добыча гравия, песка и глины
14.21	Разработка гравийных и песчаных карьеров
14.22	Добыча глины и каолина
14.3	Добыча минерального сырья для химических производств и производства  удобрений
14.30	Добыча минерального сырья для химических производств и производства удобрений
14.4	Добыча и производство соли
14.40	Добыча и производство соли
14.5	Добыча прочих полезных ископаемых, не включенных в другие группировки
14.50	Добыча прочих полезных ископаемых, не включенных в другие группировки
14.50.1	Добыча природного асфальтита и природного битума
14.50.2	Добыча драгоценных и полудрагоценных камней; добыча природных  абразивов, пемзы, асбеста, слюды, кварца и прочих неметаллических минералов, не  включенных в другие группировки
14.50.21	Добыча драгоценных и полудрагоценных камней, кроме алмазов,  самоцветов и янтаря
14.50.22	Добыча алмазов
14.50.23	Добыча природных абразивов, кроме алмазов, пемзы, наждака
14.50.24	Добыча вермикулита
14.50.25	Добыча мусковита
14.50.26	Добыча асбеста
14.50.27	Добыча пьезокварца
14.50.28	Добыча гранулированного кварца
14.50.29	Добыча и обогащение горных пород, содержащих графит и прочие  полезные ископаемые, не включенные в другие группировки
	РАЗДЕЛ D ОБРАБАТЫВАЮЩИЕ ПРОИЗВОДСТВА
	Подраздел DA ПРОИЗВОДСТВО ПИЩЕВЫХ ПРОДУКТОВ, ВКЛЮЧАЯ НАПИТКИ, И ТАБАКА
15	Производство пищевых продуктов, включая напитки
15.1	Производство мяса и мясопродуктов
15.11	Производство мяса
15.11.1	Производство мяса и пищевых субпродуктов крупного рогатого скота,  свиней, овец, коз, животных семейства лошадиных
15.11.2	Производство щипаной шерсти, сырых шкур и кож крупного рогатого скота,  животных семейства лошадиных, овец, коз и свиней
15.11.3	Производство пищевых животных жиров
15.11.4	Производство непищевых субпродуктов
15.12	Производство мяса сельскохозяйственной птицы и кроликов
15.12.1	Производство мяса и пищевых субпродуктов сельскохозяйственной птицы и кроликов
15.12.2	Производство пера и пуха
15.13	Производство продуктов из мяса и мяса птицы
15.13.1	Производство готовых и консервированных продуктов из мяса, мяса птицы,  мясных субпродуктов и крови животных
15.13.9	Предоставление услуг по тепловой обработке и прочим способам  переработки мясных продуктов
15.2	Переработка и консервирование рыбо- и морепродуктов
15.20	Переработка и консервирование рыбо- и морепродуктов
15.3	Переработка и консервирование картофеля, фруктов и овощей
15.31	Переработка и консервирование картофеля
15.32	Производство фруктовых и овощных соков
15.33	Переработка и консервирование фруктов и овощей, не включенных в другие  группировки
15.33.1	Переработка и консервирование овощей
15.33.2	Переработка и консервирование фруктов и орехов
15.33.9	Предоставление услуг по тепловой обработке и прочим способам  подготовки овощей и фруктов для консервирования
15.4	Производство растительных и животных масел и жиров
15.41	Производство неочищенных масел и жиров
15.41.1	Производство технических животных жиров, рыбьего жира и жиров морских  млекопитающих
15.41.2	Производство неочищенных растительных масел
15.42	Производство рафинированных масел и жиров
15.42.1	Производство растительных рафинированных масел и жиров
15.42.2	Производство растительного воска, кроме триглицеридов
15.43	Производство маргариновой продукции
15.43.1	Производство маргарина
15.43.2	Производство комбинированных жиров
15.5	Производство молочных продуктов
15.51	Переработка молока и производство сыра
15.51.1	Производство цельномолочной продукции
15.51.11	Производство обработанного жидкого молока
15.51.12	Производство сметаны и жидких сливок
15.51.13	Производство кисло-молочной продукции
15.51.14	Производство творога и сырково-творожных изделий
15.51.2	Производство молока, сливок и других молочных продуктов в твердых  формах
15.51.3	Производство коровьего масла
15.51.4	Производство сыра
15.51.5	Производство сгущенных молочных продуктов и молочных продуктов, не включенных в другие группировки
15.52	Производство мороженого
15.6	Производство продуктов мукомольно-крупяной промышленности, крахмалов и  крахмалопродуктов
15.61	Производство продуктов мукомольно-крупяной промышленности
15.61.1	Производство обработанного риса
15.61.2	Производство муки из зерновых и растительных культур и готовых мучных  смесей и теста для выпечки
15.61.3	Производство крупы, муки грубого помола, гранул и прочих продуктов из  зерновых культур
15.62	Производство кукурузного масла, крахмала и крахмалопродуктов
15.62.1	Производство кукурузного масла
15.62.2	Производство крахмала и крахмалопродуктов; производство сахаров и  сахарных сиропов, не включенных в другие группировки
15.7	Производство готовых кормов для животных
15.71	Производство готовых кормов и их составляющих для животных,  содержащихся на фермах
15.71.1	Производство готовых кормов (смешанных и несмешанных) для животных,  содержащихся на фермах
15.71.2	Производство кормового микробиологического белка, премиксов, кормовых  витаминов, антибиотиков, аминокислот и ферментов
15.72	Производство готовых кормов для домашних животных
15.8	Производство прочих пищевых продуктов
15.81	Производство хлеба и мучных кондитерских изделий недлительного хранения
15.82	Производство сухих хлебобулочных изделий и мучных кондитерских изделий  длительного хранения
15.83	Производство сахара
15.84	Производство какао, шоколада и сахаристых кондитерских изделий
15.84.1	Производство какао
15.84.2	Производство шоколада и сахаристых кондитерских изделий
15.85	Производство макаронных изделий
15.86	Производство чая и кофе
15.87	Производство пряностей и приправ
15.88	Производство детского питания и диетических пищевых продуктов
15.89	Производство прочих пищевых продуктов, не включенных в другие  группировки
15.89.1	Производство готовых к употреблению пищевых продуктов и заготовок для их приготовления, не включенных в другие группировки
15.89.2	Производство растительных соков и экстрактов, пептических веществ,  растительных клеев и загустителей
15.89.3	Производство пищевых ферментов
15.89.4	Переработка меда
15.9	Производство напитков
15.91	Производство дистиллированных алкогольных напитков
15.92	Производство этилового спирта из сброженных материалов
15.93	Производство виноградного вина
15.94	Производство сидра и прочих плодовых вин
15.95	Производство прочих недистиллированных напитков из сброженных  материалов
15.96	Производство пива
15.97	Производство солода
15.98	Производство минеральных вод и других безалкогольных напитков
15.98.1	Производство минеральных вод
15.98.2	Производство безалкогольных напитков, кроме минеральных вод
16	Производство табачных изделий
16.0	Производство табачных изделий
16.00	Производство табачных изделий
	Подраздел DB ТЕКСТИЛЬНОЕ И ШВЕЙНОЕ ПРОИЗВОДСТВО
17	Текстильное производство
17.1	Прядение текстильных волокон
17.11	Прядение хлопчатобумажных волокон
17.12	Кардное прядение шерстяных волокон
17.13	Гребенное прядение шерстяных волокон
17.14	Прядение льняных волокон
17.15	Изготовление натуральных шелковых, искусственных и синтетических  волокон
17.16	Производство швейных ниток
17.17	Подготовка и прядение прочих текстильных волокон
17.2	Ткацкое производство
17.21	Производство хлопчатобумажных тканей
17.22	Производство шерстяных тканей из волокон кардного прядения
17.23	Производство шерстяных тканей из волокон гребенного прядения
17.24	Производство шелковых тканей
17.25	Производство прочих текстильных тканей
17.3	Отделка тканей и текстильных изделий
17.30	Отделка тканей и текстильных изделий
17.4	Производство готовых текстильных изделий, кроме одежды
17.40	Производство готовых текстильных изделий, кроме одежды
17.5	Производство прочих текстильных изделий
17.51	Производство ковров и ковровых изделий
17.52	Производство канатов, веревок, шпагата и сетей
17.53	Производство нетканых текстильных материалов и изделий из них
17.54	Производство прочих текстильных изделий, не включенных в другие  группировки
17.54.1	Производство тюля, кружев, узких тканей, вышивок
17.54.2	Производство фетра и войлока
17.54.3	Производство текстильных изделий различного назначения, не включенных  в другие группировки
17.6	Производство трикотажного полотна
17.60	Производство трикотажного полотна
17.7	Производство трикотажных изделий
17.71	Производство чулочно-носочных изделий
17.72	Производство трикотажных джемперов, жакетов, жилетов, кардиганов и  аналогичных изделий
18	Производство одежды; выделка и крашение меха
18.1	Производство одежды из кожи
18.10	Производство одежды из кожи
18.2	Производство одежды из текстильных материалов и аксессуаров одежды
18.21	Производство спецодежды
18.22	Производство верхней одежды
18.22.1	Производство верхней трикотажной одежды
18.22.2	Производство верхней одежды из тканей для мужчин и мальчиков
18.22.3	Производство верхней одежды из тканей для женщин и девочек
18.23	Производство нательного белья
18.23.1	Производство трикотажного нательного белья
18.23.2	Производство нательного белья из тканей
18.24	Производство прочей одежды и аксессуаров
18.24.1	Производство трикотажной одежды для новорожденных детей, спортивной  одежды и аксессуаров одежды
18.24.11	Производство трикотажной одежды и аксессуаров одежды для  новорожденных детей
18.24.12	Производство трикотажных спортивных костюмов, лыжных костюмов, купальников и прочей трикотажной одежды
18.24.13	Производство трикотажных перчаток, варежек и рукавиц
18.24.14	Производство прочих трикотажных аксессуаров одежды, в том числе  платков, шарфов, галстуков и прочих аналогичных изделий
18.24.2	Производство одежды для новорожденных детей, спортивной одежды и  аксессуаров одежды из тканей
18.24.21	Производство одежды для новорожденных детей из тканей
18.24.22	Производство спортивной одежды из тканей
18.24.23	Производство аксессуаров одежды, в том числе платков, шарфов,  галстуков, перчаток и прочих аналогичных изделий из тканей
18.24.3	Производство аксессуаров одежды из кожи; производство одежды из фетра  или нетканых материалов; производство одежды из текстильных материалов с  покрытием
18.24.31	Производство аксессуаров одежды из натуральной или композиционной  кожи
18.24.32	Производство одежды из фетра, нетканых материалов, из текстильных  материалов с пропиткой или покрытием
18.24.4	Производство головных уборов
18.3	Выделка и крашение меха; производство меховых изделий
18.30	Выделка и крашение меха; производство меховых изделий
18.30.1	Выделка и крашение меха
18.30.2	Производство одежды, аксессуаров и прочих изделий из меха, кроме головных уборов
18.30.3	Производство искусственного меха и изделий из него
18.30.31	Производство искусственного меха
18.30.32	Производство изделий из искусственного меха
	Подраздел DC ПРОИЗВОДСТВО КОЖИ, ИЗДЕЛИЙ ИЗ КОЖИ И ПРОИЗВОДСТВО ОБУВИ
19	Производство кожи, изделий из кожи и производство обуви
19.1	Дубление и отделка кожи
19.10	Дубление и отделка кожи
19.2	Производство чемоданов, сумок и аналогичных изделий из кожи и других  материалов; производство шорно-седельных и других изделий из кожи
19.20	Производство чемоданов, сумок и аналогичных изделий из кожи и других  материалов; производство шорно-седельных и других изделий из кожи
19.3	Производство обуви
19.30	Производство обуви
	Подраздел DD ОБРАБОТКА ДРЕВЕСИНЫ И ПРОИЗВОДСТВО ИЗДЕЛИЙ  ИЗ ДЕРЕВА
20	Обработка древесины и производство изделий из дерева и пробки, кроме мебели
20.1	Распиловка и строгание древесины; пропитка древесины
20.10	Распиловка и строгание древесины; пропитка древесины
20.10.1	Производство пиломатериалов, кроме профилированных, толщиной более 6 мм; производство непропитанных железнодорожных и трамвайных шпал из древесины
20.10.2	Производство пиломатериалов, профилированных по кромке или по пласти;  производство древесной шерсти, древесной муки; производство технологической  щепы или стружки
20.10.3	Производство древесины, пропитанной или обработанной консервантами  или другими веществами
20.10.4	Производство биотоплива (топливные гранулы и брикеты) из отходов деревопереработки
20.10.9	Предоставление услуг по пропитке древесины
20.2	Производство шпона, фанеры, плит, панелей
20.20	Производство шпона, фанеры, плит, панелей
20.20.1	Производство клееной фанеры, щитов, древесных плит и панелей
20.20.11	Производство клееной фанеры
20.20.12	Производство древесно-стружечных плит
20.20.13	Производство древесно-волокнистых плит
20.20.14	Производство клееных щитов
20.20.19	Производство прочих древесных плит, щитов и панелей
20.20.2	Производство шпона, листов для клееной фанеры и модифицированной  древесины
20.20.21	Производство шпона и листов для клееной фанеры
20.20.22	Производство модифицированной древесины
20.3	Производство деревянных строительных конструкций, включая сборные  деревянные строения, и столярных изделий
20.30	Производство деревянных строительных конструкций, включая сборные  деревянные строения, и столярных изделий
20.30.1	Производство деревянных строительных конструкций и столярных изделий
20.30.2	Производство сборных деревянных строений
20.4	Производство деревянной тары
20.40	Производство деревянной тары
20.5	Производство прочих изделий из дерева и пробки, соломки и материалов для  плетения
20.51	Производство прочих изделий из дерева
20.51.1	Производство деревянных инструментов, корпусов и рукояток  инструментов, рукояток щеток и метелок, обувных колодок и растяжек для обуви
20.51.2	Производство деревянных столовых и кухонных принадлежностей
20.51.3	Производство деревянных статуэток и украшений из дерева, мозаики и  инкрустированного дерева, шкатулок, футляров для ювелирных изделий или  ножей
20.51.4	Производство деревянных рам для картин, фотографий, зеркал или аналогичных предметов и прочих изделий из дерева
20.52	Производство изделий из пробки, соломки и материалов для плетения
	Подраздел DE ЦЕЛЛЮЛОЗНО-БУМАЖНОЕ ПРОИЗВОДСТВО;  ИЗДАТЕЛЬСКАЯ И ПОЛИГРАФИЧЕСКАЯ ДЕЯТЕЛЬНОСТЬ
21	Производство целлюлозы, древесной массы, бумаги, картона и изделий из них
21.1	Производство целлюлозы, древесной массы, бумаги и картона
21.11	Производство целлюлозы и древесной массы
21.11.1	Производство целлюлозы
21.11.2	Производство древесной массы
21.11.3	Производство других волокнистых полуфабрикатов
21.12	Производство бумаги и картона
21.12.1	Производство бумаги
21.12.2	Производство картона
21.2	Производство изделий из бумаги и картона
21.21	Производство гофрированного картона, бумажной и картонной тары
21.22	Производство бумажных изделий хозяйственно-бытового и санитарно- гигиенического назначения
21.23	Производство писчебумажных изделий
21.24	Производство обоев
21.25	Производство прочих изделий из бумаги и картона
22	Издательская и полиграфическая деятельность, тиражирование записанных носителей информации
22.1	Издательская деятельность
22.11	Издание книг
22.11.1	Издание книг, брошюр, буклетов и аналогичных публикаций, в том числе  для слепых
22.11.2	Издание карт и атласов, в том числе для слепых
22.12	Издание газет
22.13	Издание журналов и периодических публикаций
22.14	Издание звукозаписей
22.14.1	Издание музыкальных и других звукозаписей на грампластинках, компакт-дисках, видеодисках и магнитных лентах
22.14.2	Издание нот, в том числе для слепых
22.15	Прочие виды издательской деятельности
22.2	Полиграфическая деятельность и предоставление услуг в этой области
22.21	Печатание газет
22.22	Полиграфическая деятельность, не включенная в другие группировки
22.23	Брошюровочно-переплетная деятельность
22.24	Подготовка к печати
22.25	Дополнительная деятельность, связанная с печатанием
22.3	Копирование записанных носителей информации
22.31	Копирование звукозаписей
22.32	Копирование видеозаписей
22.33	Копирование машинных носителей информации
	Подраздел DF ПРОИЗВОДСТВО КОКСА, НЕФТЕПРОДУКТОВ И ЯДЕРНЫХ  МАТЕРИАЛОВ
23	Производство кокса, нефтепродуктов и ядерных материалов
23.1	Производство кокса
23.10	Производство кокса
23.2	Производство нефтепродуктов
23.20	Производство нефтепродуктов
23.3	Производство ядерных материалов
23.30	Производство ядерных материалов
	Подраздел DG ХИМИЧЕСКОЕ ПРОИЗВОДСТВО
24	Химическое производство
24.1	Производство основных химических веществ
24.11	Производство промышленных газов
24.12	Производство красителей и пигментов
24.13	Производство прочих основных неорганических химических веществ
24.14	Производство прочих основных органических химических веществ
24.14.1	Производство синтетического и гидролизного этилового спирта
24.14.2	Производство прочих основных органических химических веществ, не включенных в другие группировки
24.15	Производство удобрений и азотных соединений
24.16	Производство пластмасс и синтетических смол в первичных формах
24.17	Производство синтетического каучука
24.2	Производство химических средств защиты растений (пестицидов) и прочих  агрохимических продуктов
24.20	Производство химических средств защиты растений (пестицидов) и прочих агрохимических продуктов
24.3	Производство красок и лаков
24.30	Производство красок и лаков
24.30.1	Производство красок и лаков на основе полимеров
24.30.2	Производство прочих красок, лаков, эмалей и связанных с ними продуктов
24.4	Производство фармацевтической продукции
24.41	Производство основной фармацевтической продукции
24.42	Производство фармацевтических препаратов и материалов
24.42.1	Производство медикаментов
24.42.2	Производство прочих фармацевтических продуктов и изделий медицинского назначения
24.5	Производство мыла; моющих, чистящих и полирующих средств; парфюмерных  и косметических средств
24.51	Производство глицерина; мыла; моющих, чистящих, полирующих средств
24.51.1	Производство глицерина
24.51.2	Производство органических поверхностно-активных веществ, кроме мыла
24.51.3	Производство мыла и моющих средств
24.51.4	Производство средств для ароматизации и дезодорирования воздуха;  производство полирующих и чистящих средств, восков
24.52	Производство парфюмерных и косметических средств
24.6	Производство прочих химических продуктов
24.61	Производство взрывчатых веществ
24.62	Производство клеев и желатина
24.63	Производство эфирных масел
24.64	Производство фотоматериалов
24.65	Производство готовых незаписанных носителей информации
24.66	Производство прочих химических продуктов
24.66.1	Производство химически модифицированных животных или растительных  жиров и масел (включая олифу), непищевых смесей животных или растительных  жиров и масел
24.66.2	Производство чернил для письма и рисования
24.66.3	Производство смазочных материалов, присадок к смазочным материалам и  антифризов
24.66.4	Производство прочих химических продуктов, не включенных в другие группировки
24.7	Производство искусственных и синтетических волокон
24.70	Производство искусственных и синтетических волокон
	Подраздел DH ПРОИЗВОДСТВО РЕЗИНОВЫХ И ПЛАСТМАССОВЫХ ИЗДЕЛИЙ
25	Производство резиновых и пластмассовых изделий
25.1	Производство резиновых изделий
25.11	Производство резиновых шин, покрышек и камер
25.12	Восстановление резиновых шин и покрышек
25.13	Производство прочих резиновых изделий
25.13.1	Производство регенерированной резины в первичной форме или в виде  пластин, листов или полос (лент)
25.13.2	Производство невулканизированного каучука и изделий из него;  производство резины в виде нити, корда, пластин, листов, полос, стержней и  профилей
25.13.3	Производство труб, трубок, рукавов и шлангов из резины
25.13.4	Производство конвейерных лент и приводных ремней из резины
25.13.5	Производство прорезиненных текстильных материалов, кроме кордной ткани
25.13.6	Производство предметов одежды и ее аксессуаров из резин
25.13.7	Производство изделий из резины, не включенных в другие группировки;  производство эбонита и изделий из него
25.2	Производство пластмассовых изделий
25.21	Производство пластмассовых плит, полос, труб и профилей
25.22	Производство пластмассовых изделий для упаковывания товаров
25.23	Производство пластмассовых изделий, используемых в строительстве
25.24	Производство прочих пластмассовых изделий
25.24.1	Производство предметов одежды и ее аксессуаров, включая перчатки, из  пластмасс
25.24.2	Производство прочих изделий из пластмасс, не включенных в другие  группировки
25.24.9	Предоставление услуг в области производства пластмассовых деталей
	Подраздел DI ПРОИЗВОДСТВО ПРОЧИХ НЕМЕТАЛЛИЧЕСКИХ МИНЕРАЛЬНЫХ ПРОДУКТОВ
26	Производство прочих неметаллических минеральных продуктов
26.1	Производство стекла и изделий из стекла
26.11	Производство листового стекла
26.12	Формование и обработка листового стекла
26.13	Производство полых стеклянных изделий
26.14	Производство стекловолокна
26.15	Производство и обработка прочих стеклянных изделий
26.15.1	Производство необработанного стекла в блоках, в виде шаров, стержней,  труб или трубок
26.15.2	Производство блоков для мощения, стеклоблоков, плит и прочих изделий из прессованного или отформованного стекла, используемых в строительстве; производство стекла для витражей; производство многоячеистого стекла или пеностекла в блоках, плитах и аналогичных формах
26.15.3	Производство открытых стеклянных колб: колб для электрических ламп,  электронно-лучевых приборов или аналогичных изделий
26.15.4	Производство стекол для часов или очков, не подвергнутых оптической  обработке
26.15.5	Производство лабораторных, фармацевтических и гигиенических изделий  из стекла; производство ампул и прочих изделий из стекла медицинского  назначения
26.15.6	Производство стеклянных деталей электрических ламп и осветительной  арматуры, световых указателей, световых табло и др.
26.15.7	Производство электрических изоляторов из стекла
26.15.8	Производство прочих изделий из стекла, не включенных в другие  группировки
26.15.81	Производство оптических элементов из стекла без оптической обработки
26.15.82	Производство кубиков для мозаичных или иных декоративных работ
26.15.83	Производство стеклянных деталей для изготовления бижутерии;  производство стеклянного бисера и бусин; производство изделий, имитирующих  жемчуг, драгоценные и полудрагоценные камни; производство стеклянных  микросфер диаметром не более 1 мм
26.15.84	Производство статуэток и прочих украшений из стекла, полученных методом выдувания из расплавленной стеклянной массы
26.15.85	Производство изделий из стекла для промышленности и сельского  хозяйства, не включенных в другие группировки: баков, чанов, резервуаров,  цилиндров, змеевиков, желобов и т.п.
26.2	Производство керамических изделий, кроме используемых в строительстве
26.21	Производство хозяйственных и декоративных керамических изделий
26.22	Производство керамических санитарно-технических изделий
26.23	Производство керамических электроизоляторов и изолирующей арматуры
26.24	Производство прочих технических керамических изделий
26.25	Производство прочих керамических изделий
26.26	Производство огнеупоров
26.3	Производство керамических плиток и плит
26.30	Производство керамических плиток и плит
26.4	Производство кирпича, черепицы и прочих строительных изделий из  обожженной глины
26.40	Производство кирпича, черепицы и прочих строительных изделий из  обожженной глины
26.5	Производство цемента, извести и гипса
26.51	Производство цемента
26.52	Производство извести
26.53	Производство гипса
26.6	Производство изделий из бетона, гипса и цемента
26.61	Производство изделий из бетона для использования в строительстве
26.62	Производство гипсовых изделий для использования в строительстве
26.63	Производство товарного бетона
26.64	Производство сухих бетонных смесей
26.65	Производство изделий из асбестоцемента и волокнистого цемента
26.66	Производство прочих изделий из бетона, гипса и цемента
26.7	Резка, обработка и отделка декоративного и строительного камня
26.70	Резка, обработка и отделка декоративного и строительного камня
26.70.1	Резка, обработка и отделка камня для использования в строительстве, в  качестве дорожного покрытия
26.70.2	Резка, обработка и отделка камня для памятников
26.70.3	Производство гранул и порошков из природного камня
26.8	Производство прочей неметаллической минеральной продукции
26.81	Производство абразивных изделий
26.82	Производство прочей неметаллической минеральной продукции, не  включенной в другие группировки
26.82.1	Производство обработанных асбестовых волокон, смесей на основе  асбеста и изделий из них
26.82.2	Производство изделий из асфальта или аналогичных материалов
26.82.3	Производство битуминозных смесей на основе природного асфальта или  битума, нефтяного битума, минеральных смол или их пеков
26.82.4	Производство искусственного графита, коллоидного или полуколлоидного  графита, продуктов на основе графита или прочих форм углерода в виде  полуфабрикатов
26.82.5	Производство искусственного корунда
26.82.6	Производство минеральных тепло- и звукоизоляционных материалов и  изделий
	Подраздел DJ МЕТАЛЛУРГИЧЕСКОЕ ПРОИЗВОДСТВО И  ПРОИЗВОДСТВО ГОТОВЫХ МЕТАЛЛИЧЕСКИХ ИЗДЕЛИЙ
27	Металлургическое производство
27.1	Производство чугуна, стали и ферросплавов
27.10	Производство чугуна, стали и ферросплавов
27.10.1	Производство чугуна и доменных ферросплавов
27.10.2	Производство продуктов прямого восстановления железной руды
27.10.3	Производство ферросплавов, кроме доменных
27.10.4	Производство стали
27.10.5	Производство полуфабрикатов (заготовок) для переката
27.10.6	Производство стального проката горячекатаного и кованого
27.10.61	Производство стального сортового проката горячекатаного и кованого
27.10.62	Производство рельсов
27.10.63	Производство сортового нержавеющего проката
27.10.64	Производство стального горячекатаного листового (плоского) проката
27.10.7	Производство холоднокатаного плоского проката без защитных покрытий и с защитными покрытиями
27.10.71	Производство холоднокатаного листового (плоского) проката без защитных покрытий
27.10.72	Производство холоднокатаного плоского проката с защитными покрытиями
27.10.73	Производство холоднокатаного листового (плоского) нержавеющего проката
27.10.74	Производство листовых штрипсов
27.10.8	Производство железных порошков, прочей металлопродукции из стального проката, не включенной в другие группировки
27.10.81	Производство железных порошков
27.10.82	Производство изделий из стального проката для верхнего строения железнодорожного пути
27.10.83	Производство профилей и конструкций шпунтового типа из стального проката
27.10.84	Производство холоднотянутого проката, включая подшипниковый
27.2	Производство чугунных и стальных труб
27.21	Производство чугунных труб и литых фитингов
27.22	Производство стальных труб и фитингов
27.22.1	Производство бесшовных горячекатаных труб
27.22.11	Производство бесшовных горячекатаных нержавеющих труб
27.22.12	Производство бесшовных горячекатаных для котлов высокого давления труб
27.22.13	Производство бесшовных горячекатаных подшипниковых труб
27.22.19	Производство бесшовных горячекатаных прочих труб
27.22.2	Производство холоднодеформированных труб
27.22.21	Производство холоднодеформированных тянутых труб
27.22.22	Производство холоднодеформированных нержавеющих труб
27.22.23	Производство холоднодеформированных для котлов высокого давления труб
27.22.24	Производство холоднодеформированных подшипниковых труб
27.22.25	Производство холоднодеформированных тонкостенных углеродистых труб
27.22.26	Производство холоднодеформированных тонкостенных легированных труб
27.22.3	Производство нарезных труб и муфт
27.22.31	Производство нарезных бурильных труб и муфт
27.22.32	Производство нарезных обсадных труб и муфт
27.22.33	Производство нарезных насосно-компрессорных труб и муфт
27.22.34	Производство нарезных электросварных труб и муфт
27.22.4	Производство сварных труб
27.22.41	Производство сварных водогазопроводных труб
27.22.42	Производство свертнопаяных труб
27.22.5	Производство электросварных труб
27.22.51	Производство электросварных с применением сварки под слоем флюса труб
27.22.52	Производство электросварных с нагревом токами высокой частоты тонкостенных труб
27.22.53	Производство электросварных с нагревом токами высокой частоты нефтепроводных труб
27.22.54	Производство электросварных с нагревом токами высокой частоты профильных труб
27.22.55	Производство электросварных с нагревом токами высокой частоты водогазопроводных труб
27.22.56	Производство электросварных нержавеющих труб
27.22.57	Производство электросварных нержавеющих холоднодеформированных труб
27.22.6	Производство муфт
27.22.61	Производство муфт для водогазопроводных труб
27.22.62	Производство муфт под сварку
27.22.63	Производство прочих соединительных деталей под сварку
27.3	Прочая первичная обработка чугуна и стали
27.31	Производство холоднотянутых прутков и профилей
27.32	Производство холоднокатаных узких полос и лент
27.33	Производство гнутых стальных профилей
27.34	Производство стальной проволоки
27.4	Производство цветных металлов
27.41	Производство драгоценных металлов
27.42	Производство алюминия
27.42.1	Производство сырья для получения алюминия
27.42.11	Производство оксида алюминия (глинозема)
27.42.12	Производство криолита и фтористого алюминия
27.42.2	Производство первичного алюминия
27.42.3	Производство алюминиевых порошков
27.42.4	Производство алюминиевых сплавов
27.42.5	Производство полуфабрикатов из алюминия или алюминиевых сплавов
27.43	Производство свинца, цинка и олова
27.43.1	Производство свинца
27.43.2	Производство цинка
27.43.3	Производство олова
27.44	Производство меди
27.45	Производство прочих цветных металлов
27.45.1	Производство никеля
27.45.2	Производство титана
27.45.3	Производство магния
27.45.4	Производство вольфрама
27.45.5	Производство молибдена
27.45.6	Производство кобальта
27.45.7	Производство редких (тантал, ниобий, галлий, германий, иридий) и редкоземельных металлов
27.5	Производство отливок
27.51	Производство чугунных отливок
27.52	Производство стальных отливок
27.53	Производство отливок из легких металлов
27.54	Производство отливок из прочих цветных металлов
28	Производство готовых металлических изделий
28.1	Производство строительных металлических конструкций и изделий
28.11	Производство строительных металлических конструкций
28.12	Производство строительных металлических изделий
28.2	Производство металлических резервуаров, радиаторов и котлов центрального  отопления
28.21	Производство металлических цистерн, резервуаров и прочих емкостей
28.22	Производство радиаторов и котлов центрального отопления
28.22.1	Производство радиаторов
28.22.2	Производство котлов центрального отопления
28.22.9	Предоставление услуг по ремонту и техническому обслуживанию котлов  центрального отопления
28.3	Производство паровых котлов, кроме котлов центрального отопления;  производство ядерных реакторов
28.30	Производство паровых котлов, кроме котлов центрального отопления;  производство ядерных реакторов
28.30.1	Производство паровых котлов, кроме котлов центрального отопления; их составных частей
28.30.2	Производство ядерных реакторов и их составных частей
28.30.9	Предоставление услуг по монтажу, техническому обслуживанию и ремонту ядерных реакторов и паровых котлов, кроме котлов центрального отопления
28.4	Ковка, прессование, штамповка и профилирование; изготовление изделий  методом порошковой металлургии
28.40	Ковка, прессование, штамповка и профилирование; изготовление изделий  методом порошковой металлургии
28.40.1	Предоставление услуг по ковке, прессованию, объемной и листовой  штамповке и профилированию листового металла
28.40.2	Предоставление услуг по производству изделий методом порошковой  металлургии
28.5	Обработка металлов и нанесение покрытий на металлы; обработка  металлических изделий с использованием основных технологических процессов  машиностроения
28.51	Обработка металлов и нанесение покрытий на металлы
28.52	Обработка металлических изделий с использованием основных технологических процессов машиностроения
28.6	Производство ножевых изделий, столовых приборов, инструментов, замочных  и скобяных изделий
28.61	Производство ножевых изделий и столовых приборов
28.62	Производство инструментов
28.63	Производство замков и петель
28.7	Производство прочих готовых металлических изделий
28.71	Производство металлических бочек и аналогичных емкостей
28.72	Производство упаковки из легких металлов
28.73	Производство изделий из проволоки
28.74	Производство крепежных изделий, цепей и пружин
28.74.1	Производство крепежных изделий и пружин
28.74.2	Производство цепей, кроме шарнирных, и составных частей к ним
28.75	Производство прочих готовых металлических изделий
28.75.1	Производство металлических изделий для ванных комнат и кухни
28.75.11	Производство раковин, моек, ванн и прочих санитарно-технических  изделий и их составных частей из черных металлов, меди или алюминия
28.75.12	Производство столовых, кухонных и прочих бытовых изделий, кроме  столовых и кухонных приборов, и их составных частей из черных металлов, меди  или алюминия
28.75.2	Производство прочих металлических изделий, кроме сабель, штыков и  аналогичного оружия
28.75.21	Производство бронированных или армированных сейфов, несгораемых  шкафов и дверей
28.75.22	Производство канцелярского настольного оборудования (ящиков, картотек,  лотков и т.п.) из недрагоценных металлов
28.75.23	Производство деталей для скоросшивателей или папок; канцелярских  принадлежностей и скоб в виде полос из недрагоценных металлов
28.75.24	Производство статуэток, рам для фотографий, картин, зеркал и прочих декоративных изделий из недрагоценных металлов
28.75.25	Производство фурнитуры из недрагоценных металлов для одежды, обуви,  кожгалантереи и прочих изделий, в том числе крючков, пряжек, застежек, петелек,  колечек, трубчатых и раздвоенных заклепок и др.
28.75.26	Производство гребных винтов и их лопастей для судовых двигателей и  лодочных моторов
28.75.27	Производство прочих изделий из недрагоценных металлов, не включенных  в другие группировки
28.75.3	Производство шпаг, кортиков, штыков, копий и аналогичного оружия и  частей к нему
	Подраздел DK ПРОИЗВОДСТВО МАШИН И ОБОРУДОВАНИЯ
29	Производство машин и оборудования
29.1	Производство механического оборудования
29.11	Производство двигателей и турбин, кроме авиационных, ракетных, автомобильных и мотоциклетных двигателей
29.11.1	Производство двигателей, кроме авиационных, ракетных, автомобильных и мотоциклетных
29.11.2	Производство турбин
29.11.21	Производство паровых турбин
29.11.22	Производство гидравлических турбин и водяных колес
29.11.23	Производство газовых турбин, кроме турбореактивных и турбовинтовых
29.11.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  двигателей и турбин, кроме авиационных, автомобильных и мотоциклетных  двигателей
29.12	Производство насосов, компрессоров и гидравлических систем
29.12.1	Производство гидравлических и пневматических силовых установок и  двигателей
29.12.2	Производство насосов для перекачки жидкостей и подъемников  жидкостей
29.12.3	Производство воздушных и вакуумных насосов; производство воздушных и  газовых компрессоров
29.12.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  насосов и компрессоров
29.13	Производство трубопроводной арматуры
29.14	Производство подшипников, зубчатых передач, элементов механических  передач и приводов
29.14.1	Производство шариковых и роликовых подшипников
29.14.2	Производство корпусов подшипников и подшипников скольжения, зубчатых  колес, зубчатых передач и элементов приводов
29.14.9	Предоставление услуг по ремонту подшипников
29.2	Производство прочего оборудования общего назначения
29.21	Производство печей и печных горелок
29.21.1	Производство неэлектрических печей, горелок и устройств для них
29.21.2	Производство электрических печей
29.21.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  печей и печных топок
29.22	Производство подъемно-транспортного оборудования
29.22.1	Производство кранов, кроме строительных
29.22.2	Производство кранов для строительства
29.22.3	Производство оборудования непрерывного транспорта
29.22.4	Производство лифтов
29.22.5	Производство авто- и электропогрузчиков
29.22.6	Производство прочего подъемно-транспортного оборудования
29.22.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию подъемно-транспортного оборудования
29.23	Производство промышленного холодильного и вентиляционного  оборудования
29.23.1	Производство теплообменных устройств, промышленного холодильного  оборудования и оборудования для кондиционирования воздуха; производство  оборудования для фильтрования и очистки газов
29.23.2	Производство вентиляторов
29.23.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  промышленного холодильного и вентиляционного оборудования
29.24	Производство прочих машин и оборудования общего назначения, не  включенных в другие группировки
29.24.1	Производство газогенераторов, аппаратов для дистилляции, фильтрования  или очистки жидкости и газов
29.24.2	Производство фасовочно-упаковочного и весоизмерительного  оборудования; производство оборудования для разбрызгивания или распыления  жидких или порошкообразных материалов
29.24.3	Производство центрифуг, каландров и торговых автоматов
29.24.31	Производство центрифуг
29.24.32	Производство каландров и прочих валковых (роликовых) машин, кроме  валковых (роликовых) машин для обработки металла и стекла
29.24.33	Производство торговых автоматов, включая автоматы для размена  денег
29.24.4	Производство оборудования, не включенного в другие группировки, для  обработки веществ с использованием процессов, предусматривающих изменение  температуры среды
29.24.6	Производство посудомоечных машин для предприятий общественного  питания
29.24.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  прочего оборудования общего назначения, не включенного в другие группировки
29.3	Производство машин и оборудования для сельского и лесного хозяйства
29.31	Производство тракторов для сельского хозяйства
29.32	Производство прочих машин и оборудования для сельского и лесного  хозяйства
29.32.1	Производство машин, используемых в растениеводстве
29.32.2	Производство машин для животноводства
29.32.3	Производство машин для лесного хозяйства
29.32.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  машин для сельского хозяйства, включая колесные тракторы, и лесного хозяйства
29.4	Производство станков
29.41	Производство переносных ручных инструментов с механическим приводом
29.42	Производство прочих станков для обработки металлов
29.42.1	Производство металлорежущих станков
29.42.2	Производство кузнечно-прессового оборудования
29.43	Производство прочих станков, не включенных в другие группировки
29.43.1	Производство деревообрабатывающего оборудования
29.43.2	Производство оборудования для пайки, сварки и резки, машин и аппаратов для поверхностной термообработки и газотермического напыления
29.5	Производство прочих машин и оборудования специального назначения
29.51	Производство машин и оборудования для металлургии
29.52	Производство машин и оборудования для добычи полезных ископаемых и строительства
29.53	Производство машин и оборудования для изготовления пищевых продуктов,  включая напитки, и табачных изделий
29.54	Производство машин и оборудования для изготовления текстильных,  швейных, меховых и кожаных изделий
29.54.1	Производство оборудования для подготовки текстильных волокон,  прядения, ткачества и вязания текстильных изделий
29.54.2	Производство прочего оборудования для текстильной и швейной  промышленности, в том числе промышленных швейных машин
29.54.3	Производство машин для подготовки, дубления и выделки шкур и кожи, для  изготовления и ремонта обуви и прочих изделий из шкур и кожи, кроме швейных  машин
29.54.4	Производство составных частей и приспособлений машин для текстильной,  швейной и кожевенной промышленности
29.54.5	Производство бытовых швейных машин
29.54.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  машин для текстильной, швейной и кожевенной промышленности
29.55	Производство машин и оборудования для изготовления бумаги и картона
29.56	Производство прочих машин и оборудования специального назначения, не  включенных в другие группировки
29.56.1	Производство переплетного, наборного, включая фотонаборные машины,  печатного оборудования и его составных частей
29.56.2	Производство разных машин и оборудования специального назначения и их составных частей
29.56.9	Предоставление услуг по монтажу, техническому обслуживанию и ремонту прочих машин и оборудования специального назначения, не включенных в другие группировки
29.6	Производство оружия и боеприпасов
29.60	Производство оружия и боеприпасов
29.7	Производство бытовых приборов, не включенных в другие группировки
29.71	Производство бытовых электрических приборов
29.72	Производство бытовых неэлектрических приборов
	Подраздел DL ПРОИЗВОДСТВО ЭЛЕКТРООБОРУДОВАНИЯ,  ЭЛЕКТРОННОГО И ОПТИЧЕСКОГО ОБОРУДОВАНИЯ
30	Производство офисного оборудования и вычислительной техники
30.0	Производство офисного оборудования и вычислительной техники
30.01	Производство офисного оборудования
30.01.1	Производство пишущих машин, машин для обработки текста,  калькуляторов, счетных машин и их частей
30.01.2	Производство фотокопировальных машин, офисных машин для офсетной  печати и прочих офисных машин и оборудования и их составных частей
30.01.9	Предоставление услуг по установке офисного оборудования
30.02	Производство электронных вычислительных машин и прочего оборудования для обработки информации
31	Производство электрических машин и электрооборудования
31.1	Производство электродвигателей, генераторов и трансформаторов
31.10	Производство электродвигателей, генераторов и трансформаторов
31.10.1	Производство электродвигателей, генераторов и трансформаторов, кроме  ремонта
31.10.9	Предоставление услуг по монтажу, ремонту, техническому обслуживанию и  перемотке электродвигателей, генераторов и трансформаторов
31.2	Производство электрической распределительной и регулирующей  аппаратуры
31.20	Производство электрической распределительной и регулирующей  аппаратуры
31.20.1	Производство электрической распределительной и регулирующей аппаратуры, кроме ремонта
31.20.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  электрической распределительной и регулирующей аппаратуры
31.3	Производство изолированных проводов и кабелей
31.30	Производство изолированных проводов и кабелей
31.4	Производство химических источников тока (аккумуляторов, первичных  элементов и батарей из них)
31.40	Производство химических источников тока (аккумуляторов, первичных  элементов и батарей из них)
31.40.1	Производство первичных элементов, батарей первичных элементов и их  частей
31.40.2	Производство электрических аккумуляторов, аккумуляторных батарей и их  частей
31.5	Производство электрических ламп и осветительного оборудования
31.50	Производство электрических ламп и осветительного оборудования
31.6	Производство прочего электрооборудования
31.61	Производство электрооборудования для двигателей и транспортных средств
31.62	Производство прочего электрооборудования, не включенного в другие  группировки, кроме электрооборудования для двигателей и транспортных средств
31.62.1	Производство, кроме ремонта, прочего электрооборудования, не  включенного в другие группировки, без электрооборудования для двигателей и  транспортных средств
31.62.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  прочего электрооборудования, не включенного в другие группировки
32	Производство электронных компонентов, аппаратуры для радио, телевидения и связи
32.1	Производство электро- и радиоэлементов, электровакуумных приборов
32.10	Производство электро- и радиоэлементов, электровакуумных приборов
32.10.1	Производство электрических конденсаторов, включая силовые
32.10.2	Производство резисторов, включая реостаты и потенциометры
32.10.3	Производство печатных схем (плат)
32.10.4	Производство электровакуумных приборов
32.10.5	Производство полупроводниковых элементов, приборов, включая  фоточувствительные и оптоэлектронные; смонтированных пьезоэлектрических  кристаллов
32.10.51	Производство полупроводниковых приборов
32.10.52	Производство смонтированных пьезоэлектрических кристаллов, включая  резонаторы, фильтры и прочие устройства
32.10.6	Производство интегральных схем, микросборок и микромодулей
32.10.7	Производство частей электровакуумных приборов и прочих электро- и  радиоэлементов, не включенных в другие группировки
32.2	Производство телевизионной и радиопередающей аппаратуры, аппаратуры электросвязи
32.20	Производство телевизионной и радиопередающей аппаратуры, аппаратуры электросвязи
32.20.1	Производство радио- и телевизионной передающей аппаратуры
32.20.2	Производство аппаратуры электросвязи
32.20.3	Производство частей радио- и телевизионной аппаратуры, аппаратуры электросвязи
32.20.4	Производство аппаратуры для передачи данных
32.20.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию телевизионной и радиопередающей аппаратуры, аппаратуры электросвязи, аппаратуры для передачи данных
32.3	Производство аппаратуры для приема, записи и воспроизведения звука и  изображения
32.30	Производство аппаратуры для приема, записи и воспроизведения звука и  изображения
32.30.1	Производство радиоприемников
32.30.2	Производство телевизионных приемников, включая видеомониторы и  видеопроекторы
32.30.3	Производство звукозаписывающей и звуковоспроизводящей аппаратуры и аппаратуры для записи и воспроизведения изображений
32.30.4	Производство электроакустической аппаратуры
32.30.5	Производство частей звукозаписывающей и звуковоспроизводящей аппаратуры и видеоаппаратуры; антенн
32.30.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию профессиональной радио-, телевизионной, звукозаписывающей и звуковоспроизводящей аппаратуры и видеоаппаратуры
33	Производство медицинских изделий; средств измерений, контроля, управления и испытаний; оптических приборов, фото- и кинооборудования; часов
33.1	Производство медицинских изделий, включая хирургическое оборудование, и ортопедических приспособлений
33.10	Производство медицинских изделий, включая хирургическое оборудование, и ортопедических приспособлений
33.10.1	Производство аппаратуры, основанной на использовании рентгеновского, альфа-, бета- и гамма-излучений; медицинского инструмента, оборудования и приспособлений; диагностической и терапевтической аппаратуры; специализированных средств защиты; их составных частей
33.10.2	Производство медицинской мебели, в том числе хирургической, стоматологической и ветеринарной; производство стоматологических и аналогичных им кресел с устройствами для поворота, подъема и наклона и их составных частей
33.10.9	Предоставление услуг по монтажу, техническому обслуживанию и ремонту медицинского оборудования и аппаратуры
33.2	Производство приборов и инструментов для измерений, контроля, испытаний, навигации, управления и прочих целей
33.20	Производство приборов и инструментов для измерений, контроля, испытаний, навигации, управления и прочих целей
33.20.1	Производство навигационных, метеорологических, геодезических, геофизических и аналогичного типа приборов, аппаратуры и инструментов
33.20.2	Производство радиолокационной, радионавигационной аппаратуры и радиоаппаратуры дистанционного управления
33.20.3	Производство точных весов; производство ручных инструментов для  черчения, разметки и математических расчетов; производство ручных инструментов  для измерения линейных размеров, не включенных в другие группировки
33.20.4	Производство приборов и аппаратуры для контроля и измерения электрических величин, ионизирующих излучений и параметров электросвязи
33.20.5	Производство приборов и аппаратуры для контроля прочих физических величин
33.20.6	Производство прочих приборов, аппаратуры и инструментов для измерения, контроля и испытаний
33.20.7	Производство приборов и аппаратуры для автоматического регулирования или управления
33.20.8	Производство частей приборов и инструментов для навигации, управления, измерения, контроля, испытаний и прочих целей
33.20.9	Предоставление услуг по монтажу, техническому обслуживанию и ремонту приборов и инструментов для измерений, контроля, испытаний, навигации, управления и прочих целей
33.3	Производство приборов контроля и регулирования технологических процессов
33.30	Производство приборов контроля и регулирования технологических процессов
33.4	Производство оптических приборов, фото- и кинооборудования
33.40	Производство оптических приборов, фото- и кинооборудования
33.40.1	Производство оптических приборов, фото- и кинооборудования, кроме ремонта
33.40.9	Предоставление услуг по ремонту и техническому обслуживанию  профессионального фото- и кинооборудования и оптических приборов
33.5	Производство часов и других приборов времени
33.50	Производство часов и других приборов времени
33.50.1	Производство готовых часов и других приборов времени
33.50.2	Производство часовых механизмов и частей часов и приборов времени
33.50.9	Предоставление услуг по монтажу, ремонту и техническому обслуживанию  промышленных приборов и аппаратуры для измерения временных интервалов
	Подраздел DM ПРОИЗВОДСТВО ТРАНСПОРТНЫХ СРЕДСТВ И  ОБОРУДОВАНИЯ
34	Производство автомобилей, прицепов и полуприцепов
34.1	Производство автомобилей
34.10	Производство автомобилей
34.10.1	Производство двигателей внутреннего сгорания для автомобилей
34.10.2	Производство легковых автомобилей
34.10.3	Производство автобусов и троллейбусов
34.10.31	Производство автобусов
34.10.32	Производство троллейбусов
34.10.4	Производство грузовых автомобилей
34.10.5	Производство автомобилей специального назначения
34.2	Производство автомобильных кузовов; производство прицепов, полуприцепов  и контейнеров, предназначенных для перевозки одним или несколькими видами  транспорта
34.20	Производство автомобильных кузовов; производство прицепов, полуприцепов  и контейнеров, предназначенных для перевозки одним или несколькими видами  транспорта
34.3	Производство частей и принадлежностей автомобилей и их двигателей
34.30	Производство частей и принадлежностей автомобилей и их двигателей
35	Производство судов, летательных и космических аппаратов и прочих транспортных средств
35.1	Строительство и ремонт судов
35.11	Строительство и ремонт судов
35.11.1	Строительство судов
35.11.9	Предоставление услуг по ремонту, техническому обслуживанию судов и переоборудованию судов
35.12	Строительство и ремонт спортивных и туристских судов
35.12.1	Строительство спортивных и туристских (прогулочных) судов
35.12.9	Предоставление услуг по ремонту, техническому обслуживанию и переоборудованию спортивных и туристских (прогулочных) судов
35.2	Производство железнодорожного подвижного состава (локомотивов,  трамвайных моторных вагонов и прочего подвижного состава)
35.20	Производство железнодорожного подвижного состава (локомотивов,  трамвайных моторных вагонов и прочего подвижного состава)
35.20.1	Производство железнодорожных локомотивов
35.20.2	Производство моторных железнодорожных, трамвайных вагонов и вагонов  метро, автомотрис и автодрезин, кроме транспортных средств для ремонта и  технического обслуживания железнодорожных и трамвайных путей
35.20.3	Производство прочего подвижного состава
35.20.31	Производство транспортных средств для ремонта и технического  обслуживания железнодорожных, трамвайных и прочих путей
35.20.32	Производство несамоходных пассажирских железнодорожных, трамвайных  вагонов и вагонов метро, багажных, почтовых и прочих вагонов специального  назначения, кроме вагонов, предназначенных для ремонта и технического  обслуживания путей
35.20.33	Производство несамоходных железнодорожных, трамвайных и прочих  вагонов для перевозки грузов
35.20.4	Производство частей железнодорожных локомотивов, трамвайных и прочих  моторных вагонов и подвижного состава; производство путевого оборудования и устройств для железнодорожных, трамвайных и прочих путей, механического и электромеханического оборудования для управления движением
35.20.9	Предоставление услуг по ремонту, техническому обслуживанию и  переделке железнодорожных локомотивов, трамвайных и прочих моторных вагонов  и подвижного состава
35.3	Производство летательных аппаратов, включая космические
35.30	Производство летательных аппаратов, включая космические
35.30.1	Производство силовых установок и двигателей для летательных аппаратов, включая космические; устройств для ускоренного взлета самолетов, палубных тормозных устройств; наземных тренажеров для летного состава; их частей
35.30.11	Производство двигателей летательных аппаратов с искровым зажиганием  и их частей
35.30.12	Производство турбореактивных и турбовинтовых двигателей и их частей
35.30.13	Производство реактивных двигателей, включая ракетные, и их частей
35.30.14	Производство устройств для ускоренного взлета самолетов, палубных тормозных устройств и аналогичных устройств
35.30.17	Производство наземных тренажеров для летного состава и их частей
35.30.2	Производство воздушных шаров, дирижаблей, планеров, дельтапланов и  прочих безмоторных летательных аппаратов
35.30.3	Производство вертолетов, самолетов и прочих летательных аппаратов
35.30.4	Производство космических аппаратов, ракет-носителей и прочих космических объектов
35.30.41	Производство автоматических космических аппаратов
35.30.42	Производство пилотируемых и беспилотных космических кораблей и станций, включая орбитальные, межпланетные, многоразового использования и др.
35.30.43	Производство средств выведения космических объектов в космическое пространство
35.30.49	Производство прочих космических объектов, не включенных в другие группировки
35.30.5	Производство прочих частей и принадлежностей летательных аппаратов, включая части космических объектов и средств их выведения в космическое пространство
35.30.9	Предоставление услуг по монтажу, техническому обслуживанию, ремонту и восстановлению летательных аппаратов и двигателей летательных аппаратов, включая составные части ракет космического назначения
35.4	Производство мотоциклов и велосипедов
35.41	Производство мотоциклов, мопедов и мотоциклетных колясок
35.42	Производство велосипедов
35.43	Производство инвалидных колясок
35.5	Производство прочих транспортных средств и оборудования, не включенных в  другие группировки
35.50	Производство прочих транспортных средств и оборудования, не включенных  в другие группировки
	Подраздел DN ПРОЧИЕ ПРОИЗВОДСТВА
36	Производство мебели и прочей продукции, не включенной в другие группировки
36.1	Производство мебели
36.11	Производство стульев и другой мебели для сидения
36.12	Производство мебели для офисов и предприятий торговли
36.13	Производство кухонной мебели
36.14	Производство прочей мебели
36.15	Производство матрасов
36.2	Производство ювелирных изделий, медалей и технических изделий из драгоценных металлов и драгоценных камней; производство монет
36.21	Чеканка монет
36.22	Производство ювелирных изделий, медалей и технических изделий из драгоценных металлов и драгоценных камней
36.22.1	Производство изделий технического назначения из драгоценных металлов
36.22.2	Производство изделий технического назначения из драгоценных камней
36.22.3	Обработка алмазов
36.22.4	Обработка драгоценных, кроме алмазов, полудрагоценных, поделочных и  синтетических камней
36.22.5	Производство ювелирных изделий, медалей из драгоценных металлов и драгоценных камней
36.3	Производство музыкальных инструментов
36.30	Производство музыкальных инструментов
36.4	Производство спортивных товаров
36.40	Производство спортивных товаров
36.5	Производство игр и игрушек
36.50	Производство игр и игрушек
36.6	Производство различной продукции, не включенной в другие группировки
36.61	Производство ювелирных изделий из недрагоценных материалов
36.62	Производство метел и щеток
36.63	Производство прочей продукции, не включенной в другие группировки
36.63.1	Производство каруселей, качелей, тиров и прочих ярмарочных  аттракционов
36.63.2	Производство пишущих принадлежностей
36.63.3	Производство зонтов, тростей, пуговиц, кнопок, застежек-молний
36.63.4	Производство линолеума на текстильной основе
36.63.5	Производство изделий из волоса человека или животных; производство  аналогичных изделий из текстильных материалов
36.63.6	Производство спичек и зажигалок
36.63.7	Производство прочих изделий, не включенных в другие группировки
36.63.8	Производство изделий народных художественных промыслов
37	Обработка вторичного сырья
37.1	Обработка металлических отходов и лома
37.10	Обработка металлических отходов и лома
37.10.1	Обработка отходов и лома черных металлов
37.10.2	Обработка отходов и лома цветных металлов
37.10.21	Обработка отходов и лома цветных металлов, кроме драгоценных
37.10.22	Обработка отходов и лома драгоценных металлов
37.2	Обработка неметаллических отходов и лома
37.20	Обработка неметаллических отходов и лома
37.20.1	Обработка отходов резины
37.20.2	Обработка отходов и лома пластмасс
37.20.3	Обработка отходов и лома стекла
37.20.4	Обработка отходов текстильных материалов
37.20.5	Обработка отходов бумаги и картона
37.20.6	Обработка отходов драгоценных камней
37.20.7	Обработка прочих неметаллических отходов и лома
	РАЗДЕЛ E ПРОИЗВОДСТВО И РАСПРЕДЕЛЕНИЕ ЭЛЕКТРОЭНЕРГИИ, ГАЗА И ВОДЫ
	Подраздел EА ПРОИЗВОДСТВО И РАСПРЕДЕЛЕНИЕ ЭЛЕКТРОЭНЕРГИИ, ГАЗА И ВОДЫ
40	Производство, передача и распределение электроэнергии, газа, пара и горячей воды
40.1	Производство, передача и распределение электроэнергии
40.11	Производство электроэнергии
40.11.1	Производство электроэнергии тепловыми электростанциями
40.11.2	Производство электроэнергии гидроэлектростанциями
40.11.3	Производство электроэнергии атомными электростанциями
40.11.4	Производство электроэнергии прочими электростанциями и промышленными блок-станциями
40.11.5	Деятельность по обеспечению работоспособности электростанций
40.11.51	Деятельность по обеспечению работоспособности тепловых электростанций
40.11.52	Деятельность по обеспечению работоспособности гидроэлектростанций
40.11.53	Деятельность по обеспечению работоспособности атомных электростанций
40.11.54	Деятельность по обеспечению работоспособности прочих электростанций и промышленных блок-станций
40.12	Передача электроэнергии
40.13	Распределение электроэнергии и торговля электроэнергией
40.13.1	Распределение электроэнергии
40.13.2	Торговля электроэнергией
40.13.3	Деятельность по обеспечению работоспособности электрических сетей
40.2	Производство и распределение газообразного топлива
40.21	Производство газа
40.22	Распределение газообразного топлива; торговля газообразным топливом, подаваемым по распределительным сетям
40.22.1	Распределение газообразного топлива
40.22.2	Торговля газообразным топливом, подаваемым по распределительным сетям
40.3	Производство, передача и распределение пара и горячей воды (тепловой  энергии)
40.30	Производство, передача и распределение пара и горячей воды (тепловой энергии)
40.30.1	Производство пара и горячей воды (тепловой энергии)
40.30.11	Производство пара и горячей воды (тепловой энергии) тепловыми  электростанциями
40.30.12	Производство пара и горячей воды (тепловой энергии) атомными  электростанциями
40.30.13	Производство пара и горячей воды (тепловой энергии) прочими  электростанциями и промышленными блок-станциями
40.30.14	Производство пара и горячей воды (тепловой энергии) котельными
40.30.17	Производство охлажденной воды или льда (натурального из воды) для  охлаждения
40.30.2	Передача пара и горячей воды (тепловой энергии)
40.30.3	Распределение пара и горячей воды (тепловой энергии)
40.30.4	Деятельность по обеспечению работоспособности котельных
40.30.5	Деятельность по обеспечению работоспособности тепловых сетей
40.30.6	Торговля паром и горячей водой (тепловой энергией)
41	Сбор, очистка и распределение воды
41.0	Сбор, очистка и распределение воды
41.00	Сбор, очистка и распределение воды
41.00.1	Сбор и очистка воды
41.00.2	Распределение воды
	РАЗДЕЛ F   СТРОИТЕЛЬСТВО
	Подраздел FА СТРОИТЕЛЬСТВО
45	Строительство
45.1	Подготовка строительного участка
45.11	Разборка и снос зданий; производство земляных работ
45.11.1	Разборка и снос зданий, расчистка строительных участков
45.11.2	Производство земляных работ
45.11.3	Подготовка участка для горных работ
45.12	Разведочное бурение
45.2	Строительство зданий и сооружений
45.21	Производство общестроительных работ
45.21.1	Производство общестроительных работ по возведению зданий
45.21.2	Производство общестроительных работ по строительству мостов, надземных автомобильных дорог, тоннелей и подземных дорог
45.21.3	Производство общестроительных работ по прокладке магистральных трубопроводов, линий связи и линий электропередачи
45.21.4	Производство общестроительных работ по прокладке местных трубопроводов, линий связи и линий электропередачи, включая взаимосвязанные вспомогательные работы
45.21.5	Производство общестроительных работ по строительству электростанций и  сооружений для горнодобывающей и обрабатывающей промышленности
45.21.51	Производство общестроительных работ по строительству гидроэлектростанций
45.21.52	Производство общестроительных работ по строительству атомных электростанций
45.21.53	Производство общестроительных работ по строительству тепловых и прочих электростанций
45.21.54	Производство общестроительных работ по строительству сооружений для горнодобывающей и обрабатывающей промышленности
45.21.6	Производство общестроительных работ по строительству прочих зданий и сооружений, не включенных в другие группировки
45.21.7	Монтаж зданий и сооружений из сборных конструкций
45.22	Устройство покрытий зданий и сооружений
45.23	Строительство дорог, аэродромов и спортивных сооружений
45.23.1	Производство общестроительных работ по строительству автомобильных дорог, железных дорог и взлетно-посадочных полос аэродромов
45.23.2	Строительство спортивных сооружений
45.24	Строительство водных сооружений
45.24.1	Строительство портовых сооружений
45.24.2	Строительство гидротехнических сооружений
45.24.3	Производство дноуглубительных и берегоукрепительных работ
45.24.4	Производство подводных работ, включая водолазные
45.25	Производство прочих строительных работ
45.25.1	Монтаж строительных лесов и подмостей
45.25.2	Строительство фундаментов и бурение водяных скважин
45.25.3	Производство бетонных и железобетонных работ
45.25.4	Монтаж металлических строительных конструкций
45.25.5	Производство каменных работ
45.25.6	Производство прочих строительных работ, требующих специальной квалификации
45.3	Монтаж инженерного оборудования зданий и сооружений
45.31	Производство электромонтажных работ
45.32	Производство изоляционных работ
45.33	Производство санитарно-технических работ
45.34	Монтаж прочего инженерного оборудования
45.4	Производство отделочных работ
45.41	Производство штукатурных работ
45.42	Производство столярных и плотничных работ
45.43	Устройство покрытий полов и облицовка стен
45.44	Производство малярных и стекольных работ
45.44.1	Производство стекольных работ
45.44.2	Производство малярных работ
45.45	Производство прочих отделочных и завершающих работ
45.5	Аренда строительных машин и оборудования с оператором
45.50	Аренда строительных машин и оборудования с оператором
	РАЗДЕЛ G ОПТОВАЯ И РОЗНИЧНАЯ ТОРГОВЛЯ; РЕМОНТ АВТОТРАНСПОРТНЫХ СРЕДСТВ, МОТОЦИКЛОВ, БЫТОВЫХ ИЗДЕЛИЙ И ПРЕДМЕТОВ ЛИЧНОГО ПОЛЬЗОВАНИЯ
	Подраздел GА ОПТОВАЯ И РОЗНИЧНАЯ ТОРГОВЛЯ; РЕМОНТ АВТОТРАНСПОРТНЫХ СРЕДСТВ, МОТОЦИКЛОВ, БЫТОВЫХ ИЗДЕЛИЙ И ПРЕДМЕТОВ ЛИЧНОГО ПОЛЬЗОВАНИЯ
50	Торговля автотранспортными средствами и мотоциклами, их техническое обслуживание и ремонт
50.1	Торговля автотранспортными средствами
50.10	Торговля автотранспортными средствами
50.10.1	Оптовая торговля автотранспортными средствами
50.10.2	Розничная торговля автотранспортными средствами
50.10.3	Торговля автотранспортными средствами через агентов
50.2	Техническое обслуживание и ремонт автотранспортных средств
50.20	Техническое обслуживание и ремонт автотранспортных средств
50.20.1	Техническое обслуживание и ремонт легковых автомобилей
50.20.2	Техническое обслуживание и ремонт прочих автотранспортных средств
50.20.3	Предоставление прочих видов услуг по техническому обслуживанию автотранспортных средств
50.3	Торговля автомобильными деталями, узлами и принадлежностями
50.30	Торговля автомобильными деталями, узлами и принадлежностями
50.30.1	Оптовая торговля автомобильными деталями, узлами и принадлежностями
50.30.2	Розничная торговля автомобильными деталями, узлами и  принадлежностями
50.30.3	Торговля автомобильными деталями, узлами и принадлежностями через агентов
50.4	Торговля мотоциклами, их деталями, узлами и принадлежностями;  техническое обслуживание и ремонт мотоциклов
50.40	Торговля мотоциклами, их деталями, узлами и принадлежностями; техническое обслуживание и ремонт мотоциклов
50.40.1	Оптовая торговля мотоциклами, их деталями, узлами и принадлежностями
50.40.2	Розничная торговля мотоциклами, их деталями, узлами и принадлежностями
50.40.3	Торговля мотоциклами, их деталями, узлами и принадлежностями через агентов
50.40.4	Техническое обслуживание и ремонт мотоциклов
50.5	Розничная торговля моторным топливом
50.50	Розничная торговля моторным топливом
51	Оптовая торговля, включая торговлю через агентов, кроме торговли автотранспортными средствами и мотоциклами
51.1	Оптовая торговля через агентов (за вознаграждение или на договорной основе)
51.11	Деятельность агентов по оптовой торговле живыми животными,  сельскохозяйственным сырьем, текстильным сырьем и полуфабрикатами
51.11.1	Деятельность агентов по оптовой торговле живыми животными
51.11.2	Деятельность агентов по оптовой торговле сельскохозяйственным сырьем,  текстильным сырьем и полуфабрикатами
51.11.21	Деятельность агентов по оптовой торговле зерном
51.11.22	Деятельность агентов по оптовой торговле семенами, кроме масличных
51.11.23	Деятельность агентов по оптовой торговле масличными семенами и  маслосодержащими плодами
51.11.24	Деятельность агентов по оптовой торговле кормами для сельскохозяйственных животных
51.11.25	Деятельность агентов по оптовой торговле текстильным сырьем и полуфабрикатами
51.11.26	Деятельность агентов по оптовой торговле прочими сельскохозяйственным сырьем и полуфабрикатами, не включенными в другие группировки
51.12	Деятельность агентов по оптовой торговле топливом, рудами, металлами и химическими веществами
51.12.1	Деятельность агентов по оптовой торговле топливом
51.12.2	Деятельность агентов по оптовой торговле рудами и металлами
51.12.21	Деятельность агентов по оптовой торговле рудами
51.12.22	Деятельность агентов по оптовой торговле черными металлами
51.12.23	Деятельность агентов по оптовой торговле цветными металлами, кроме драгоценных
51.12.24	Деятельность агентов по оптовой торговле драгоценными металлами
51.12.3	Деятельность агентов по оптовой торговле химическими веществами
51.12.31	Деятельность агентов по оптовой торговле непищевым этиловым спиртом, включая денатурат
51.12.32	Деятельность агентов по оптовой торговле удобрениями, пестицидами и прочими агрохимикатами
51.12.33	Деятельность агентов по оптовой торговле пластмассами и синтетическими смолами в первичных формах
51.12.34	Деятельность агентов по оптовой торговле химическими волокнами
51.12.35	Деятельность агентов по оптовой торговле синтетическим каучуком и резиной в первичных формах
51.12.36	Деятельность агентов по оптовой торговле взрывчатыми веществами
51.12.37	Деятельность агентов по оптовой торговле прочими основными химическими веществами
51.13	Деятельность агентов по оптовой торговле лесоматериалами и строительными материалами
51.13.1	Деятельность агентов по оптовой торговле лесоматериалами
51.13.2	Деятельность агентов по оптовой торговле строительными материалами
51.14	Деятельность агентов по оптовой торговле машинами, оборудованием, судами и летательными аппаратами
51.14.1	Деятельность агентов по оптовой торговле офисным оборудованием и вычислительной техникой
51.14.2	Деятельность агентов по оптовой торговле прочими видами машин и оборудования
51.14.3	Деятельность агентов по оптовой торговле судами и летательными  аппаратами
51.15	Деятельность агентов по оптовой торговле мебелью, бытовыми товарами,  скобяными, ножевыми и прочими металлическими изделиями
51.15.1	Деятельность агентов по оптовой торговле бытовой мебелью
51.15.2	Деятельность агентов по оптовой торговле скобяными, ножевыми и прочими бытовыми металлическими изделиями
51.15.3	Деятельность агентов по оптовой торговле электротоварами и бытовыми  электроустановочными изделиями
51.15.4	Деятельность агентов по оптовой торговле радио- и телеаппаратурой, техническими носителями информации (с записями и без записей)
51.15.41	Деятельность агентов по оптовой торговле радио- и телеаппаратурой
51.15.42	Деятельность агентов по оптовой торговле техническими носителями информации (с записями и без записей)
51.15.5	Деятельность агентов по оптовой торговле прочими бытовыми товарами хозяйственного назначения
51.16	Деятельность агентов по оптовой торговле текстильными изделиями, одеждой, обувью, изделиями из кожи и меха
51.16.1	Деятельность агентов по оптовой торговле текстильными изделиями
51.16.2	Деятельность агентов по оптовой торговле одеждой, включая одежду из кожи, аксессуарами одежды и обувью
51.16.3	Деятельность агентов по оптовой торговле изделиями из кожи и меха
51.17	Деятельность агентов по оптовой торговле пищевыми продуктами, включая  напитки, и табачными изделиями
51.17.1	Деятельность агентов по оптовой торговле пищевыми продуктами
51.17.2	Деятельность агентов по оптовой торговле напитками
51.17.21	Деятельность агентов по оптовой торговле безалкогольными напитками
51.17.22	Деятельность агентов по оптовой торговле алкогольными напитками, кроме пива
51.17.23	Деятельность агентов по оптовой торговле пивом
51.17.3	Деятельность агентов по оптовой торговле табачными изделиями
51.18	Деятельность агентов, специализирующихся на оптовой торговле отдельными видами товаров или группами товаров, не включенными в другие группировки
51.18.1	Деятельность агентов, специализирующихся на оптовой торговле фармацевтическими и медицинскими товарами, парфюмерными и косметическими товарами, включая мыло
51.18.2	Деятельность агентов, специализирующихся на оптовой торговле товарами,  не включенными в другие группировки
51.18.21	Деятельность агентов по оптовой торговле бумагой и бумажными  изделиями
51.18.22	Деятельность агентов по оптовой торговле книгами
51.18.23	Деятельность агентов по оптовой торговле газетами и журналами
51.18.24	Деятельность агентов по оптовой торговле драгоценными камнями
51.18.25	Деятельность агентов по оптовой торговле ювелирными изделиями
51.18.27	Деятельность агентов по оптовой торговле прочими товарами, не включенными в другие группировки
51.19	Деятельность агентов по оптовой торговле универсальным ассортиментом товаров
51.2	Оптовая торговля сельскохозяйственным сырьем и живыми животными
51.21	Оптовая торговля зерном, семенами и кормами для сельскохозяйственных  животных
51.21.1	Оптовая торговля зерном
51.21.2	Оптовая торговля семенами, кроме масличных семян
51.21.3	Оптовая торговля масличными семенами и маслосодержащими плодами
51.21.4	Оптовая торговля кормами для сельскохозяйственных животных
51.21.5	Оптовая торговля сельскохозяйственным сырьем, не включенным в другие  группировки
51.22	Оптовая торговля цветами и другими растениями
51.23	Оптовая торговля живыми животными
51.24	Оптовая торговля шкурами и кожей
51.25	Оптовая торговля необработанным табаком
51.3	Оптовая торговля пищевыми продуктами, включая напитки, и табачными изделиями
51.31	Оптовая торговля фруктами, овощами и картофелем
51.31.1	Оптовая торговля картофелем
51.31.2	Оптовая торговля непереработанными овощами, фруктами и орехами
51.32	Оптовая торговля мясом, мясом птицы, продуктами и консервами из мяса и мяса птицы
51.32.1	Оптовая торговля мясом и мясом птицы, включая субпродукты
51.32.11	Оптовая торговля мясом, включая субпродукты
51.32.12	Оптовая торговля мясом птицы, включая субпродукты
51.32.2	Оптовая торговля продуктами из мяса и мяса птицы
51.32.3	Оптовая торговля консервами из мяса и мяса птицы
51.33	Оптовая торговля молочными продуктами, яйцами, пищевыми маслами и жирами
51.33.1	Оптовая торговля молочными продуктами
51.33.2	Оптовая торговля яйцами
51.33.3	Оптовая торговля пищевыми маслами и жирами
51.34	Оптовая торговля алкогольными и другими напитками
51.34.1	Оптовая торговля безалкогольными напитками
51.34.2	Оптовая торговля алкогольными напитками, включая пиво
51.34.21	Оптовая торговля алкогольными напитками, кроме пива
51.34.22	Оптовая торговля пивом
51.35	Оптовая торговля табачными изделиями
51.36	Оптовая торговля сахаром и сахаристыми кондитерскими изделиями, включая шоколад
51.36.1	Оптовая торговля сахаром
51.36.2	Оптовая торговля сахаристыми кондитерскими изделиями, включая шоколад, мороженым и замороженными десертами
51.36.21	Оптовая торговля сахаристыми кондитерскими изделиями, включая шоколад
51.36.22	Оптовая торговля мороженым и замороженными десертами
51.36.3	Оптовая торговля хлебом и хлебобулочными изделиями
51.36.4	Оптовая торговля мучными кондитерскими изделиями
51.37	Оптовая торговля кофе, чаем, какао и пряностями
51.38	Оптовая торговля прочими пищевыми продуктами
51.38.1	Оптовая торговля рыбой, морепродуктами и рыбными консервами
51.38.2	Оптовая торговля прочими пищевыми продуктами
51.38.21	Оптовая торговля переработанными овощами, картофелем, фруктами и орехами
51.38.22	Оптовая торговля готовыми пищевыми продуктами, включая торговлю детским и диетическим питанием и прочими гомогенизированными пищевыми продуктами
51.38.23	Оптовая торговля кормами для домашних животных
51.38.26	Оптовая торговля мукой и макаронными изделиями
51.38.27	Оптовая торговля крупами
51.38.28	Оптовая торговля солью
51.38.29	Оптовая торговля прочими пищевыми продуктами, не включенными в другие группировки
51.39	Неспециализированная оптовая торговля пищевыми продуктами, включая  напитки, и табачными изделиями
51.39.1	Неспециализированная оптовая торговля замороженными пищевыми  продуктами
51.39.2	Неспециализированная оптовая торговля незамороженными пищевыми  продуктами, напитками и табачными изделиями
51.4	Оптовая торговля непродовольственными потребительскими товарами
51.41	Оптовая торговля текстильными и галантерейными изделиями
51.41.1	Оптовая торговля текстильными изделиями, кроме текстильных галантерейных изделий
51.41.2	Оптовая торговля галантерейными изделиями
51.42	Оптовая торговля одеждой, включая нательное белье, и обувью
51.42.1	Оптовая торговля одеждой, кроме нательного белья
51.42.2	Оптовая торговля нательным бельем
51.42.3	Оптовая торговля изделиями из меха
51.42.4	Оптовая торговля обувью
51.42.5	Оптовая торговля аксессуарами одежды и головными уборами
51.43	Оптовая торговля бытовыми электротоварами, радио- и телеаппаратурой
51.43.1	Оптовая торговля бытовыми электротоварами
51.43.2	Оптовая торговля радио- и телеаппаратурой, техническими носителями  информации (с записями и без записей)
51.43.21	Оптовая торговля радио- и телеаппаратурой
51.43.22	Оптовая торговля техническими носителями информации (с записями и без записей)
51.44	Оптовая торговля изделиями из керамики и стекла, обоями, чистящими средствами
51.44.1	Оптовая торговля ножевыми изделиями и бытовой металлической посудой
51.44.2	Оптовая торговля изделиями из керамики и стекла
51.44.3	Оптовая торговля обоями
51.44.4	Оптовая торговля чистящими средствами
51.45	Оптовая торговля парфюмерными и косметическими товарами
51.45.1	Оптовая торговля парфюмерными и косметическими товарами, кроме мыла
51.45.2	Оптовая торговля туалетным и хозяйственным мылом
51.46	Оптовая торговля фармацевтическими и медицинскими товарами, изделиями  медицинской техники и ортопедическими изделиями
51.46.1	Оптовая торговля фармацевтическими и медицинскими товарами
51.46.2	Оптовая торговля изделиями медицинской техники и ортопедическими изделиями
51.47	Оптовая торговля прочими непродовольственными потребительскими товарами
51.47.1	Оптовая торговля бытовой мебелью, напольными покрытиями и прочими  неэлектрическими бытовыми товарами
51.47.11	Оптовая торговля бытовой мебелью
51.47.12	Оптовая торговля неэлектрическими бытовыми приборами
51.47.13	Оптовая торговля плетеными изделиями, изделиями из пробки, бондарными изделиями и изделиями из дерева
51.47.14	Оптовая торговля напольными покрытиями
51.47.15	Оптовая торговля бытовыми товарами, не включенными в другие группировки
51.47.2	Оптовая торговля книгами, газетами и журналами, писчебумажными и  канцелярскими товарами
51.47.21	Оптовая торговля книгами
51.47.22	Оптовая торговля газетами и журналами
51.47.23	Оптовая торговля писчебумажными и канцелярскими товарами
51.47.3	Оптовая торговля прочими потребительскими товарами
51.47.31	Оптовая торговля музыкальными инструментами и нотными изданиями
51.47.32	Оптовая торговля фототоварами и оптическими товарами
51.47.33	Оптовая торговля играми и игрушками
51.47.34	Оптовая торговля ювелирными изделиями
51.47.35	Оптовая торговля спортивными товарами, включая велосипеды
51.47.36	Оптовая торговля изделиями из кожи и дорожными принадлежностями
51.47.37	Оптовая торговля прочими потребительскими товарами, не включенными в другие группировки
51.5	Оптовая торговля несельскохозяйственными промежуточными продуктами, отходами и ломом
51.51	Оптовая торговля топливом
51.51.1	Оптовая торговля твердым топливом
51.51.2	Оптовая торговля моторным топливом, включая авиационный бензин
51.51.3	Оптовая торговля сырой нефтью
51.51.4	Оптовая торговля прочим жидким и газообразным топливом
51.52	Оптовая торговля металлами и металлическими рудами
51.52.1	Оптовая торговля металлическими рудами
51.52.11	Оптовая торговля железными рудами
51.52.12	Оптовая торговля рудами цветных металлов
51.52.2	Оптовая торговля металлами в первичных формах
51.52.21	Оптовая торговля черными металлами в первичных формах
51.52.22	Оптовая торговля цветными металлами в первичных формах, кроме драгоценных
51.52.23	Оптовая торговля золотом и другими драгоценными металлами
51.53	Оптовая торговля лесоматериалами, строительными материалами и санитарно-техническим оборудованием
51.53.1	Оптовая торговля лесоматериалами
51.53.2	Оптовая торговля лакокрасочными материалами, листовым стеклом,  санитарно-техническим оборудованием и прочими строительными материалами
51.53.21	Оптовая торговля санитарно-техническим оборудованием
51.53.22	Оптовая торговля лакокрасочными материалами
51.53.23	Оптовая торговля материалами для остекления
51.53.24	Оптовая торговля прочими строительными материалами
51.54	Оптовая торговля скобяными изделиями, ручными инструментами,  водопроводным и отопительным оборудованием
51.54.1	Оптовая торговля скобяными изделиями
51.54.2	Оптовая торговля водопроводным и отопительным оборудованием
51.54.3	Оптовая торговля ручными инструментами
51.55	Оптовая торговля химическими продуктами
51.55.1	Оптовая торговля удобрениями, пестицидами и другими агрохимикатами
51.55.11	Оптовая торговля удобрениями
51.55.12	Оптовая торговля пестицидами и другими агрохимикатами
51.55.2	Оптовая торговля синтетическими смолами и пластмассами в первичных формах
51.55.3	Оптовая торговля прочими промышленными химическими веществами
51.55.31	Оптовая торговля непищевым этиловым спиртом, включая денатурат
51.55.32	Оптовая торговля синтетическим каучуком и резиной в первичных формах
51.55.33	Оптовая торговля взрывчатыми веществами
51.55.34	Оптовая торговля прочими промышленными химическими веществами, не включенными в другие группировки
51.56	Оптовая торговля прочими промежуточными продуктами
51.56.1	Оптовая торговля бумагой и картоном
51.56.2	Оптовая торговля текстильными волокнами
51.56.3	Оптовая торговля драгоценными камнями
51.56.5	Оптовая торговля прочими промежуточными продуктами, кроме сельскохозяйственных, не включенными в другие группировки
51.57	Оптовая торговля отходами и ломом
51.8	Оптовая торговля машинами и оборудованием
51.81	Оптовая торговля станками
51.81.1	Оптовая торговля деревообрабатывающими станками
51.81.2	Оптовая торговля станками для обработки металлов
51.81.3	Оптовая торговля станками для обработки прочих материалов
51.82	Оптовая торговля машинами и оборудованием для добычи полезных ископаемых и строительства
51.83	Оптовая торговля машинами и оборудованием для текстильного, швейного и трикотажного производств
51.84	Оптовая торговля компьютерами, периферийными устройствами и программным обеспечением
51.85	Оптовая торговля офисными машинами и оборудованием
51.85.1	Оптовая торговля офисными машинами
51.85.2	Оптовая торговля офисной мебелью
51.86	Оптовая торговля прочими электронными деталями (частями) и оборудованием
51.87	Оптовая торговля прочими машинами и оборудованием
51.87.1	Оптовая торговля транспортными средствами и оборудованием, кроме автомобилей, мотоциклов и велосипедов
51.87.2	Оптовая торговля эксплуатационными материалами и принадлежностями машин и оборудования
51.87.3	Оптовая торговля подъемно-транспортными машинами и оборудованием
51.87.4	Оптовая торговля машинами и оборудованием для производства пищевых продуктов, напитков и табачных изделий
51.87.5	Оптовая торговля производственным электрическим оборудованием, машинами, аппаратурой и материалами
51.87.6	Оптовая торговля прочими машинами, приборами, аппаратурой и оборудованием общепромышленного и специального назначения
51.88	Оптовая торговля машинами, оборудованием и инструментами для сельского хозяйства, включая тракторы
51.88.1	Оптовая торговля тракторами
51.88.2	Оптовая торговля прочими машинами, оборудованием и инструментами для сельского и лесного хозяйства
51.9	Прочая оптовая торговля
51.90	Прочая оптовая торговля
52	Розничная торговля, кроме торговли автотранспортными средствами и мотоциклами; ремонт бытовых изделий и предметов личного пользования
52.1	Розничная торговля в неспециализированных магазинах
52.11	Розничная торговля в неспециализированных магазинах преимущественно пищевыми продуктами, включая напитки, и табачными изделиями
52.11.1	Розничная торговля в неспециализированных магазинах замороженными  продуктами
52.11.2	Розничная торговля в неспециализированных магазинах незамороженными  продуктами, включая напитки, и табачными изделиями
52.12	Прочая розничная торговля в неспециализированных магазинах
52.2	Розничная торговля пищевыми продуктами, включая напитки, и табачными  изделиями в специализированных магазинах
52.21	Розничная торговля фруктами, овощами и картофелем
52.22	Розничная торговля мясом, мясом птицы, продуктами и консервами из мяса и мяса птицы
52.22.1	Розничная торговля мясом и мясом птицы, включая субпродукты
52.22.2	Розничная торговля продуктами из мяса и мяса птицы
52.22.3	Розничная торговля консервами из мяса и мяса птицы
52.23	Розничная торговля рыбой, ракообразными и моллюсками
52.23.1	Розничная торговля рыбой и морепродуктами
52.23.2	Розничная торговля консервами из рыбы и морепродуктов
52.24	Розничная торговля хлебом, хлебобулочными и кондитерскими изделиями
52.24.1	Розничная торговля хлебом и хлебобулочными изделиями
52.24.2	Розничная торговля кондитерскими изделиями
52.24.21	Розничная торговля мучными кондитерскими изделиями
52.24.22	Розничная торговля сахаристыми кондитерскими изделиями, включая  шоколад
52.24.3	Розничная торговля мороженым и замороженными десертами
52.25	Розничная торговля алкогольными и другими напитками
52.25.1	Розничная торговля алкогольными напитками, включая пиво
52.25.11	Розничная торговля алкогольными напитками, кроме пива
52.25.12	Розничная торговля пивом
52.25.2	Розничная торговля безалкогольными напитками
52.26	Розничная торговля табачными изделиями
52.27	Прочая розничная торговля пищевыми продуктами в специализированных  магазинах
52.27.1	Розничная торговля молочными продуктами и яйцами
52.27.11	Розничная торговля молочными продуктами
52.27.12	Розничная торговля яйцами
52.27.2	Розничная торговля пищевыми маслами и жирами
52.27.21	Розничная торговля животными маслами и жирами
52.27.22	Розничная торговля растительными маслами
52.27.3	Розничная торговля прочими пищевыми продуктами
52.27.31	Розничная торговля мукой и макаронными изделиями
52.27.32	Розничная торговля крупами
52.27.33	Розничная торговля консервированными фруктами, овощами, орехами и  т.п.
52.27.34	Розничная торговля сахаром
52.27.35	Розничная торговля солью
52.27.36	Розничная торговля чаем, кофе, какао
52.27.39	Розничная торговля прочими пищевыми продуктами, не включенными в  другие группировки
52.3	Розничная торговля фармацевтическими и медицинскими товарами,  косметическими и парфюмерными товарами
52.31	Розничная торговля фармацевтическими товарами
52.32	Розничная торговля медицинскими товарами и ортопедическими изделиями
52.33	Розничная торговля косметическими и парфюмерными товарами
52.33.1	Розничная торговля косметическими и парфюмерными товарами, кроме мыла
52.33.2	Розничная торговля туалетным и хозяйственным мылом
52.4	Прочая розничная торговля в специализированных магазинах
52.41	Розничная торговля текстильными и галантерейными изделиями
52.41.1	Розничная торговля текстильными изделиями
52.41.2	Розничная торговля галантерейными изделиями
52.42	Розничная торговля одеждой
52.42.1	Розничная торговля мужской, женской и детской одеждой
52.42.2	Розничная торговля нательным бельем
52.42.3	Розничная торговля изделиями из меха
52.42.4	Розничная торговля одеждой из кожи
52.42.5	Розничная торговля спортивной одеждой
52.42.6	Розничная торговля чулочно-носочными изделиями
52.42.7	Розничная торговля головными уборами
52.42.8	Розничная торговля аксессуарами одежды (перчатками, галстуками, шарфами, ремнями, подтяжками и т.п.)
52.43	Розничная торговля обувью и изделиями из кожи
52.43.1	Розничная торговля обувью
52.43.2	Розничная торговля изделиями из кожи и дорожными принадлежностями
52.44	Розничная торговля мебелью и товарами для дома
52.44.1	Розничная торговля мебелью
52.44.2	Розничная торговля различной домашней утварью, ножевыми изделиями, посудой, изделиями из стекла и керамики, в том числе фарфора и фаянса
52.44.3	Розничная торговля светильниками
52.44.4	Розничная торговля портьерами, тюлевыми занавесями и другими  предметами домашнего обихода из текстильных материалов
52.44.5	Розничная торговля изделиями из дерева, пробки и плетеными изделиями
52.44.6	Розничная торговля бытовыми изделиями и приборами, не включенными в  другие группировки
52.45	Розничная торговля бытовыми электротоварами, радио- и телеаппаратурой
52.45.1	Розничная торговля бытовыми электротоварами
52.45.2	Розничная торговля радио- и телеаппаратурой
52.45.3	Розничная торговля аудио- и видеоаппаратурой
52.45.4	Розничная торговля техническими носителями информации (с записями и без записей)
52.45.5	Розничная торговля музыкальными инструментами и нотными изданиями
52.46	Розничная торговля скобяными изделиями, лакокрасочными материалами и  материалами для остекления
52.46.1	Розничная торговля скобяными изделиями
52.46.2	Розничная торговля красками, лаками и эмалями
52.46.3	Розничная торговля материалами для остекления
52.46.4	Розничная торговля материалами и оборудованием для изготовления поделок
52.46.5	Розничная торговля санитарно-техническим оборудованием
52.46.6	Розничная торговля садово-огородной техникой и инвентарем
52.46.7	Розничная торговля строительными материалами, не включенными в другие  группировки
52.46.71	Розничная торговля лесоматериалами
52.46.72	Розничная торговля кирпичом
52.46.73	Розничная торговля металлическими и неметаллическими конструкциями и  т.п.
52.46.74	Розничная торговля сборными деревянными строениями
52.47	Розничная торговля книгами, журналами, газетами, писчебумажными и  канцелярскими товарами
52.47.1	Розничная торговля книгами
52.47.2	Розничная торговля газетами и журналами
52.47.3	Розничная торговля писчебумажными и канцелярскими товарами
52.48	Прочая розничная торговля в специализированных магазинах
52.48.1	Специализированная розничная торговля офисной мебелью, офисным  оборудованием, компьютерами, оптическими приборами и фотоаппаратурой
52.48.11	Розничная торговля офисной мебелью
52.48.12	Розничная торговля офисными машинами и оборудованием
52.48.13	Розничная торговля компьютерами, программным обеспечением и периферийными устройствами
52.48.14	Розничная торговля фотоаппаратурой, оптическими приборами и средствами измерений, кроме очков
52.48.15	Розничная торговля очками, включая сборку и ремонт очков
52.48.16	Розничная торговля оборудованием электросвязи
52.48.2	Специализированная розничная торговля часами, ювелирными изделиями,  спортивными товарами, играми и игрушками
52.48.21	Розничная торговля часами
52.48.22	Розничная торговля ювелирными изделиями
52.48.23	Розничная торговля спортивными товарами, рыболовными принадлежностями, туристским снаряжением, лодками и велосипедами
52.48.24	Розничная торговля играми и игрушками
52.48.3	Специализированная розничная торговля непродовольственными товарами, не включенными в другие группировки
52.48.31	Розничная торговля товарами бытовой химии, синтетическими моющими средствами, обоями и напольными покрытиями
52.48.32	Розничная торговля цветами и другими растениями, семенами и удобрениями
52.48.33	Розничная торговля домашними животными и кормом для домашних животных
52.48.34	Розничная торговля сувенирами, изделиями народных художественных промыслов, предметами культового и религиозного назначения, похоронными принадлежностями
52.48.35	Розничная торговля бытовым жидким котельным топливом, газом в  баллонах, углем, древесным топливом, топливным торфом
52.48.36	Розничная торговля филателистическими и нумизматическими товарами
52.48.37	Розничная торговля произведениями искусства в коммерческих художественных галереях
52.48.38	Розничная торговля пиротехническими средствами
52.48.39	Специализированная розничная торговля прочими непродовольственными  товарами, не включенными в другие группировки
52.5	Розничная торговля бывшими в употреблении товарами в магазинах
52.50	Розничная торговля бывшими в употреблении товарами в магазинах
52.50.1	Розничная торговля предметами антиквариата
52.50.2	Розничная торговля букинистическими книгами
52.50.3	Розничная торговля прочими бывшими в употреблении товарами
52.6	Розничная торговля вне магазинов
52.61	Розничная торговля по заказам
52.61.1	Розничная почтовая (посылочная) торговля
52.61.2	Розничная торговля, осуществляемая непосредственно при помощи телевидения, радио, телефона и Интернет
52.62	Розничная торговля в палатках и на рынках
52.63	Прочая розничная торговля вне магазинов
52.7	Ремонт бытовых изделий и предметов личного пользования
52.71	Ремонт обуви и прочих изделий из кожи
52.72	Ремонт бытовых электрических изделий
52.72.1	Ремонт радио- и телеаппаратуры и прочей аудио- и видеоаппаратуры
52.72.2	Ремонт прочих бытовых электрических изделий
52.73	Ремонт часов и ювелирных изделий
52.74	Ремонт бытовых изделий и предметов личного пользования, не включенных в другие группировки
	РАЗДЕЛ H   ГОСТИНИЦЫ И РЕСТОРАНЫ
	Подраздел HА ГОСТИНИЦЫ И РЕСТОРАНЫ
55	Деятельность гостиниц и ресторанов
55.1	Деятельность гостиниц
55.10	Деятельность гостиниц
55.2	Деятельность прочих мест для временного проживания
55.21	Деятельность молодежных туристских лагерей и горных туристских баз
55.22	Деятельность кемпингов
55.23	Деятельность прочих мест для проживания
55.23.1	Деятельность детских лагерей на время каникул
55.23.2	Деятельность пансионатов, домов отдыха и т.п.
55.23.3	Сдача внаем для временного проживания меблированных комнат
55.23.4	Предоставление мест для временного проживания в железнодорожных спальных вагонах и прочих транспортных средствах
55.23.5	Деятельность прочих мест для временного проживания, не включенных в другие группировки
55.3	Деятельность ресторанов
55.30	Деятельность ресторанов и кафе
55.4	Деятельность баров
55.40	Деятельность баров
55.5	Деятельность столовых при предприятиях и учреждениях и поставка продукции  общественного питания
55.51	Деятельность столовых при предприятиях и учреждениях
55.52	Поставка продукции общественного питания
	РАЗДЕЛ I ТРАНСПОРТ И СВЯЗЬ
	Подраздел IА ТРАНСПОРТ И СВЯЗЬ
60	Деятельность сухопутного транспорта
60.1	Деятельность железнодорожного транспорта
60.10	Деятельность железнодорожного транспорта
60.10.1	Деятельность магистрального железнодорожного транспорта
60.10.11	Деятельность магистрального пассажирского железнодорожного транспорта
60.10.12	Деятельность магистрального грузового железнодорожного транспорта
60.10.2	Деятельность промышленного железнодорожного транспорта
60.2	Деятельность прочего сухопутного транспорта
60.21	Деятельность прочего сухопутного пассажирского транспорта, подчиняющегося расписанию
60.21.1	Деятельность автомобильного (автобусного) пассажирского транспорта,  подчиняющегося расписанию
60.21.11	Внутригородские автомобильные (автобусные) пассажирские перевозки,  подчиняющиеся расписанию
60.21.12	Пригородные автомобильные (автобусные) пассажирские перевозки,  подчиняющиеся расписанию
60.21.13	Междугородные автомобильные (автобусные) пассажирские перевозки,  подчиняющиеся расписанию
60.21.14	Международные автомобильные (автобусные) пассажирские перевозки, подчиняющиеся расписанию
60.21.2	Деятельность городского электрического транспорта
60.21.21	Деятельность трамвайного транспорта
60.21.22	Деятельность троллейбусного транспорта
60.21.23	Деятельность метрополитена
60.21.24	Внутригородские и пригородные пассажирские перевозки наземным железнодорожным транспортом
60.21.3	Пассажирские перевозки фуникулерами, воздушными канатными дорогами  и подъемниками
60.22	Деятельность такси
60.23	Деятельность прочего сухопутного пассажирского транспорта
60.24	Деятельность автомобильного грузового транспорта
60.24.1	Деятельность автомобильного грузового специализированного транспорта
60.24.2	Деятельность автомобильного грузового неспециализированного транспорта
60.24.3	Аренда грузового автомобильного транспорта с водителем
60.3	Транспортирование по трубопроводам
60.30	Транспортирование по трубопроводам
60.30.1	Транспортирование по трубопроводам нефти и нефтепродуктов
60.30.11	Транспортирование по трубопроводам нефти
60.30.12	Транспортирование по трубопроводам нефтепродуктов
60.30.2	Транспортирование по трубопроводам газа и продуктов его переработки
60.30.21	Транспортирование по трубопроводам газа
60.30.22	Транспортирование по трубопроводам продуктов переработки газа
60.30.3	Транспортирование по трубопроводам прочих видов грузов
61	Деятельность водного транспорта
61.1	Деятельность морского транспорта
61.10	Деятельность морского транспорта
61.10.1	Деятельность морского пассажирского транспорта
61.10.2	Деятельность морского грузового транспорта
61.10.21	Деятельность по перевозке сухих грузов морским транспортом
61.10.22	Деятельность по перевозке наливных грузов морским транспортом
61.10.29	Деятельность по перевозке прочих грузов морским транспортом
61.10.3	Аренда морских транспортных средств с экипажем; предоставление маневровых услуг
61.10.31	Аренда морских транспортных средств с экипажем
61.10.32	Предоставление маневровых услуг на морском транспорте, включая буксировку судов и иных плавучих средств
61.2	Деятельность внутреннего водного транспорта
61.20	Деятельность внутреннего водного транспорта
61.20.1	Деятельность внутреннего водного пассажирского транспорта
61.20.2	Деятельность внутреннего водного грузового транспорта
61.20.3	Аренда внутренних водных транспортных средств с экипажем; предоставление маневровых услуг
61.20.4	Деятельность по обеспечению лесосплава (без сплава в плотах судовой  тягой)
62	Деятельность воздушного и космического транспорта
62.1	Деятельность воздушного транспорта, подчиняющегося расписанию
62.10	Деятельность воздушного транспорта, подчиняющегося расписанию
62.10.1	Деятельность воздушного пассажирского транспорта, подчиняющегося  расписанию
62.10.2	Деятельность воздушного грузового транспорта, подчиняющегося расписанию
62.2	Деятельность воздушного транспорта, не подчиняющегося расписанию
62.20	Деятельность воздушного транспорта, не подчиняющегося расписанию
62.20.1	Деятельность воздушного пассажирского транспорта, не подчиняющегося  расписанию
62.20.2	Деятельность воздушного грузового транспорта, не подчиняющегося  расписанию
62.20.3	Аренда воздушного транспорта с экипажем
62.3	Деятельность космического транспорта
62.30	Деятельность космического транспорта
62.30.1	Выведение космических объектов в космическое пространство
62.30.11	Подготовка ракет космического назначения к пуску
62.30.12	Запуск космических объектов в космическое пространство
62.30.2	Управление космическими объектами в космическом пространстве
63	Вспомогательная и дополнительная транспортная деятельность
63.1	Транспортная обработка грузов и хранение
63.11	Транспортная обработка грузов
63.11.1	Транспортная обработка контейнеров
63.11.2	Транспортная обработка прочих грузов
63.12	Хранение и складирование
63.12.1	Хранение и складирование замороженных или охлажденных грузов
63.12.2	Хранение и складирование жидких или газообразных грузов
63.12.21	Хранение и складирование нефти и продуктов ее переработки
63.12.22	Хранение и складирование газа и продуктов его переработки
63.12.23	Хранение и складирование прочих жидких или газообразных грузов
63.12.3	Хранение и складирование зерна
63.12.4	Хранение и складирование прочих грузов
63.2	Прочая вспомогательная транспортная деятельность
63.21	Прочая вспомогательная деятельность сухопутного транспорта
63.21.1	Прочая вспомогательная деятельность железнодорожного транспорта
63.21.11	Деятельность терминалов (железнодорожных станций, перегрузочных товарных станций и т.п.)
63.21.12	Эксплуатация железнодорожных сооружений
63.21.13	Техническое обслуживание и мелкий ремонт подвижного состава
63.21.2	Прочая вспомогательная деятельность автомобильного транспорта
63.21.21	Деятельность терминалов (автобусных станций и т.п.)
63.21.22	Эксплуатация автомобильных дорог общего пользования
63.21.23	Эксплуатация дорожных сооружений (мостов, туннелей, путепроводов и  т.п.)
63.21.24	Эксплуатация гаражей, стоянок для автотранспортных средств, велосипедов и т.п.
63.22	Прочая вспомогательная деятельность водного транспорта
63.22.1	Прочая вспомогательная деятельность морского транспорта
63.22.11	Деятельность по эксплуатации морских портов, пристаней, шлюзов и т.п., включая деятельность по обслуживанию пассажиров в портах
63.22.12	Лоцманская проводка судов на морском транспорте
63.22.13	Деятельность по постановке судов к причалу, осуществление швартования судов в портах на морском транспорте
63.22.14	Навигационное обеспечение судоходства на морском транспорте (деятельность береговых служб, радиолокационных станций управления движением судов, обеспечение средствами навигационного оборудования)
63.22.15	Аварийно-спасательная и судоподъемная деятельность на морском транспорте
63.22.16	Снабженческое (шипчандлерское) обслуживание судов, включая бункеровку судов топливом, обслуживание судов в период стоянки в портах: агентирование судов, обследовательское (сюрвейерское) обслуживание судов на морском транспорте
63.22.17	Производство водолазных работ по обслуживанию морских судов
63.22.18	Деятельность ледокольного флота на морском транспорте
63.22.19	Прочая вспомогательная деятельность морского транспорта, не включенная в другие группировки
63.22.2	Прочая вспомогательная деятельность внутреннего водного транспорта
63.22.21	Деятельность по эксплуатации портов, пристаней, шлюзов и т.п. внутреннего водного транспорта, включая деятельность по обслуживанию пассажиров в портах
63.22.22	Лоцманская проводка судов на внутреннем водном транспорте
63.22.23	Деятельность по постановке судов к причалу, осуществление швартования судов в портах на внутреннем водном транспорте
63.22.24	Навигационное обеспечение судоходства на внутреннем водном транспорте (деятельность береговых служб, радиолокационных станций управления движением судов, обеспечение средствами навигационного оборудования)
63.22.25	Аварийно-спасательная и судоподъемная деятельность на внутреннем водном транспорте
63.22.26	Снабженческое (шипчандлерское) обслуживание судов, включая бункеровку судов топливом, обслуживание судов в период стоянки в портах: агентирование судов, обследовательское (сюрвейерское) обслуживание судов на внутреннем водном транспорте
63.22.27	Производство водолазных работ по обслуживанию судов на внутреннем водном транспорте
63.22.28	Деятельность ледокольного флота на внутреннем водном транспорте
63.22.29	Прочая вспомогательная деятельность внутреннего водного транспорта, не включенная в другие группировки
63.23	Прочая вспомогательная деятельность воздушного и космического транспорта
63.23.1	Деятельность терминалов (аэропортов и т.п.), управление аэропортами
63.23.2	Управление воздушным движением
63.23.3	Эксплуатация взлетно-посадочных полос, ангаров и т.п.
63.23.4	Деятельность по наземному обслуживанию воздушных судов
63.23.5	Деятельность школ повышения квалификации (учебно-тренировочных  центров) для пилотов коммерческих авиалиний
63.23.6	Вспомогательная деятельность, связанная с использованием (эксплуатацией) космического транспорта
63.23.61	Содержание и эксплуатация объектов наземной космической инфраструктуры и их составных частей
63.23.62	Предоставление услуг по транспортировке составных частей ракет космического назначения на космодромы (полигоны) и их хранению, а также по доставке эксплуатационного расчета и космонавтов
63.23.63	Предоставление услуг по поставке и транспортированию компонентов ракетного топлива и сжатых газов для ракет космического назначения (ракет) на космодромы (полигоны) и их хранению
63.23.64	Предоставление услуг поисково-спасательных служб
63.23.65	Подготовка космонавтов для работы непосредственно в космическом пространстве
63.23.68	Предоставление услуг, связанных с подготовкой к запуску и пуском ракет космического назначения, не включенных в другие группировки
63.23.69	Прочие вспомогательные услуги, связанные с использованием (эксплуатацией) космических транспортных средств, не включенные в другие группировки
63.3	Деятельность туристических агентств
63.30	Деятельность туристических агентств
63.30.1	Организация комплексного туристического обслуживания
63.30.2	Обеспечение экскурсионными билетами, обеспечение проживания,  обеспечение транспортными средствами
63.30.3	Предоставление туристических информационных услуг
63.30.4	Предоставление туристических экскурсионных услуг
63.4	Организация перевозок грузов
63.40	Организация перевозок грузов
64	Связь
64.1	Почтовая и курьерская деятельность
64.11	Деятельность национальной почты
64.11.1	Деятельность почтовой связи общего пользования
64.11.11	Деятельность почтовой связи, связанная с пересылкой газет и других периодических изданий
64.11.12	Деятельность почтовой связи, связанная с пересылкой письменной корреспонденции
64.11.13	Деятельность почтовой связи, связанная с пересылкой посылочной почты
64.11.14	Дополнительная деятельность почтовой связи
64.11.15	Прочая деятельность почтовой связи
64.11.2	Деятельность специальной почтовой связи
64.11.3	Деятельность фельдъегерской связи
64.11.31	Деятельность федеральной фельдъегерской связи
64.11.32	Деятельность фельдъегерско-почтовой связи
64.12	Курьерская деятельность, кроме деятельности национальной почты
64.2	Деятельность в области электросвязи
64.20	Деятельность в области электросвязи
64.20.1	Деятельность в области телефонной связи
64.20.11	Деятельность в области фиксированной телефонной связи
64.20.12	Деятельность в области подвижной связи
64.20.2	Деятельность в области телеграфной связи
64.20.3	Деятельность в области оказания услуг межсистемной связи
64.20.4	Деятельность в области передачи данных
64.20.5	Деятельность в области оказания телематических услуг связи
64.20.6	Деятельность в области кабельного вещания, эфирного вещания и проводного радиовещания
64.20.7	Прочая деятельность в области электросвязи
	РАЗДЕЛ J   ФИНАНСОВАЯ ДЕЯТЕЛЬНОСТЬ
	Подраздел JА ФИНАНСОВАЯ ДЕЯТЕЛЬНОСТЬ
65	Финансовое посредничество
65.1	Денежное посредничество
65.11	Деятельность Центрального банка Российской Федерации
65.11.1	Разработка и проведение во взаимодействии с Правительством Российской Федерации единой государственной денежно-кредитной политики
65.11.11	Осуществление эмиссии наличных денег и организация наличного денежного обращения
65.11.12	Выполнение функции кредитора последней инстанции для кредитных организаций, организация системы их рефинансирования
65.11.9	Прочая деятельность Центрального банка Российской Федерации
65.12	Прочее денежное посредничество
65.2	Прочее финансовое посредничество
65.21	Финансовый лизинг
65.21.1	Финансовый лизинг племенных животных
65.21.2	Финансовый лизинг в прочих областях, кроме племенных животных
65.22	Предоставление кредита
65.22.1	Предоставление потребительского кредита
65.22.2	Предоставление займов промышленности
65.22.3	Предоставление денежных ссуд под залог недвижимого имущества
65.22.4	Предоставление кредитов на покупку домов специализированными учреждениями, не принимающими депозиты
65.22.5	Предоставление услуг по обеспечению кредитных карточек
65.22.6	Предоставление ломбардами краткосрочных кредитов под залог движимого имущества
65.22.7	Предоставление услуг по факторингу
65.22.8	Предоставление услуг по залоговым операциям
65.22.9	Предоставление услуг доверительного управления активами
65.23	Финансовое посредничество, не включенное в другие группировки
65.23.1	Капиталовложения в ценные бумаги
65.23.2	Деятельность дилеров
65.23.3	Капиталовложения в собственность
65.23.4	Заключение свопов, опционов и других биржевых сделок
65.23.5	Деятельность холдинг-компаний в области финансового посредничества
66	Страхование
66.0	Страхование
66.01	Страхование жизни
66.02	Добровольное пенсионное страхование
66.02.1	Деятельность по добровольному пенсионному страхованию
66.02.2	Страхование ренты
66.03	Прочие виды страхования
66.03.1	Добровольное медицинское страхование
66.03.2	Страхование имущества
66.03.3	Страхование ответственности
66.03.4	Страхование от несчастных случаев и болезней
66.03.5	Страхование рисков
66.03.9	Прочие виды страхования, не включенные в другие группировки
67	Вспомогательная деятельность в сфере финансового посредничества и страхования
67.1	Вспомогательная деятельность в сфере финансового посредничества
67.11	Управление финансовыми рынками
67.11.1	Деятельность фондовых, товарных, валютных и валютно-фондовых бирж
67.11.11	Деятельность по организации торговли на финансовых рынках
67.11.12	Деятельность по ведению реестра владельцев ценных бумаг (деятельность регистраторов)
67.11.13	Деятельность по обеспечению эффективности функционирования финансовых рынков
67.11.14	Деятельность по определению взаимных обязательств (клиринг)
67.11.19	Прочая деятельность, связанная с управлением финансовыми рынками, не включенная в другие группировки
67.12	Биржевые операции с фондовыми ценностями и управление активами
67.12.1	Брокерская деятельность
67.12.2	Деятельность по управлению ценными бумагами
67.12.4	Эмиссионная деятельность
67.13	Прочая вспомогательная деятельность в сфере финансового посредничества
67.13.1	Предоставление брокерских услуг по ипотечным операциям
67.13.2	Предоставление услуг пунктами по обмену валют
67.13.3	Предоставление услуг по упаковыванию денег
67.13.4	Консультирование по вопросам финансового посредничества
67.13.5	Предоставление услуг по хранению ценностей
67.13.51	Депозитарная деятельность
67.2	Вспомогательная деятельность в сфере страхования и негосударственного  пенсионного обеспечения
67.20	Вспомогательная деятельность в сфере страхования и негосударственного пенсионного обеспечения
67.20.1	Деятельность страховых агентов
67.20.2	Деятельность специалистов по оценке страхового риска и убытков
67.20.3	Деятельность специалистов по расчетам оценки страховой вероятности (актуариев)
67.20.4	Деятельность распорядителей спасательными работами
67.20.9	Прочая вспомогательная деятельность в сфере страхования, кроме обязательного социального страхования
	РАЗДЕЛ K ОПЕРАЦИИ С НЕДВИЖИМЫМ ИМУЩЕСТВОМ, АРЕНДА И ПРЕДОСТАВЛЕНИЕ УСЛУГ
	Подраздел KА ОПЕРАЦИИ С НЕДВИЖИМЫМ ИМУЩЕСТВОМ, АРЕНДА И ПРЕДОСТАВЛЕНИЕ УСЛУГ
70	Операции с недвижимым имуществом
70.1	Подготовка к продаже, покупка и продажа собственного недвижимого  имущества
70.11	Подготовка к продаже собственного недвижимого имущества
70.11.1	Подготовка к продаже собственного жилого недвижимого имущества
70.11.2	Подготовка к продаже собственного нежилого недвижимого имущества
70.12	Покупка и продажа собственного недвижимого имущества
70.12.1	Покупка и продажа собственного жилого недвижимого имущества
70.12.2	Покупка и продажа собственных нежилых зданий и помещений
70.12.3	Покупка и продажа земельных участков
70.2	Сдача внаем собственного недвижимого имущества
70.20	Сдача внаем собственного недвижимого имущества
70.20.1	Сдача внаем собственного жилого недвижимого имущества
70.20.2	Сдача внаем собственного нежилого недвижимого имущества
70.3	Предоставление посреднических услуг, связанных с недвижимым  имуществом
70.31	Деятельность агентств по операциям с недвижимым имуществом
70.31.1	Предоставление посреднических услуг при покупке, продаже и аренде недвижимого имущества
70.31.11	Предоставление посреднических услуг при покупке, продаже и аренде жилого недвижимого имущества
70.31.12	Предоставление посреднических услуг при покупке, продаже и аренде нежилого недвижимого имущества
70.31.2	Предоставление посреднических услуг при оценке недвижимого имущества
70.31.21	Предоставление посреднических услуг при оценке жилого недвижимого имущества
70.31.22	Предоставление посреднических услуг при оценке нежилого недвижимого имущества
70.32	Управление недвижимым имуществом
70.32.1	Управление эксплуатацией жилого фонда
70.32.2	Управление эксплуатацией нежилого фонда
70.32.3	Деятельность по учету и технической инвентаризации недвижимого имущества
71	Аренда машин и оборудования без оператора; прокат бытовых изделий и предметов личного пользования
71.1	Аренда легковых автомобилей
71.10	Аренда легковых автомобилей
71.2	Аренда прочих транспортных средств и оборудования
71.21	Аренда прочих сухопутных транспортных средств и оборудования
71.21.1	Аренда прочего автомобильного транспорта и оборудования
71.21.2	Аренда железнодорожного транспорта и оборудования
71.22	Аренда водных транспортных средств и оборудования
71.23	Аренда воздушных транспортных средств и оборудования
71.3	Аренда прочих машин и оборудования
71.31	Аренда сельскохозяйственных машин и оборудования
71.31.1	Аренда сельскохозяйственных машин, оборудования и племенных животных
71.31.11	Аренда сельскохозяйственных машин и оборудования
71.31.12	Аренда (лизинг) племенных животных
71.32	Аренда строительных машин и оборудования
71.33	Аренда офисных машин и оборудования, включая вычислительную технику
71.33.1	Аренда офисных машин и оборудования
71.33.2	Аренда вычислительных машин и оборудования
71.34	Аренда прочих машин и оборудования, не включенных в другие группировки
71.34.1	Аренда двигателей, турбин и станков
71.34.2	Аренда горного и нефтепромыслового оборудования
71.34.3	Аренда подъемно-транспортного оборудования
71.34.4	Аренда профессиональной радио- и телевизионной аппаратуры и аппаратуры связи
71.34.5	Аренда контрольно-измерительной аппаратуры
71.34.6	Аренда медицинской техники
71.34.7	Аренда торгового оборудования
71.34.9	Аренда прочих машин и оборудования научного и промышленного назначения
71.4	Прокат бытовых изделий и предметов личного пользования
71.40	Прокат бытовых изделий и предметов личного пользования
71.40.1	Прокат телевизоров, радиоприемников, устройств видеозаписи, аудиозаписи и подобного оборудования
71.40.2	Прокат аудио- и видеокассет, грампластинок и записей на других технических носителях информации
71.40.3	Прокат мебели, электрических и неэлектрических бытовых приборов
71.40.4	Прокат инвентаря и оборудования для проведения досуга и отдыха
71.40.5	Прокат музыкальных инструментов
71.40.6	Прокат предметов медицинского и санитарного обслуживания
71.40.9	Прокат прочих бытовых изделий и предметов личного пользования для домашних хозяйств, предприятий и организаций, не включенных в другие группировки
72	Деятельность, связанная с использованием вычислительной техники и информационных технологий
72.1	Консультирование по аппаратным средствам вычислительной техники
72.10	Консультирование по аппаратным средствам вычислительной техники
72.2	Разработка программного обеспечения и консультирование в этой области
72.21	Разработка программного обеспечения
72.22	Прочая деятельность по разработке программного обеспечения и консультированию в этой области
72.3	Обработка данных
72.30	Обработка данных
72.4	Деятельность по созданию и использованию баз данных и информационных ресурсов, в том числе ресурсов сети Интернет
72.40	Деятельность по созданию и использованию баз данных и информационных ресурсов, в том числе ресурсов сети Интернет
72.5	Техническое обслуживание и ремонт офисных машин и вычислительной техники
72.50	Техническое обслуживание и ремонт офисных машин и вычислительной техники
72.6	Прочая деятельность, связанная с использованием вычислительной техники и информационных технологий
72.60	Прочая деятельность, связанная с использованием вычислительной техники и информационных технологий
73	Научные исследования и разработки
73.1	Научные исследования и разработки в области естественных и технических наук
73.10	Научные исследования и разработки в области естественных и технических наук
73.2	Научные исследования и разработки в области общественных и гуманитарных наук
73.20	Научные исследования и разработки в области общественных и гуманитарных наук
74	Предоставление прочих видов услуг
74.1	Деятельность в области права, бухгалтерского учета и аудита; консультирование по вопросам коммерческой деятельности и управления предприятием
74.11	Деятельность в области права
74.12	Деятельность в области бухгалтерского учета и аудита
74.12.1	Деятельность в области бухгалтерского учета
74.12.2	Аудиторская деятельность
74.13	Маркетинговые исследования и выявление общественного мнения
74.13.1	Маркетинговые исследования
74.13.2	Деятельность по изучению общественного мнения
74.14	Консультирование по вопросам коммерческой деятельности и управления
74.15	Деятельность по управлению финансово-промышленными группами и холдинг-компаниями
74.15.1	Деятельность по управлению финансово-промышленными группами
74.15.2	Деятельность по управлению холдинг-компаниями
74.2	Деятельность в области архитектуры; инженерно-техническое проектирование; геолого-разведочные и геофизические работы; геодезическая и картографическая деятельность; деятельность в области стандартизации и метрологии; деятельность в области гидрометеорологии и смежных с ней областях; виды деятельности, связанные с решением технических задач, не включенные в другие группировки
74.20	Деятельность в области архитектуры; инженерно-техническое проектирование; геолого-разведочные и геофизические работы; геодезическая и картографическая деятельность; деятельность в области стандартизации и метрологии; деятельность в области гидрометеорологии и смежных с ней областях, мониторинга состояния окружающей среды, ее загрязнения; виды деятельности, связанные с решением технических задач, не включенные в другие группировки
74.20.1	Деятельность в области архитектуры, инженерно-техническое проектирование в промышленности и строительстве
74.20.11	Архитектурная деятельность
74.20.12	Проектирование производственных помещений, включая размещение машин и оборудования
74.20.13	Проектирование, связанное со строительством инженерных сооружений, включая гидротехнические сооружения; проектирование движения транспортных потоков
74.20.14	Разработка проектов промышленных процессов и производств, относящихся к электротехнике, электронной технике, горному делу, химической  технологии, машиностроению, а также в области промышленного строительства, системотехники и техники безопасности
74.20.15	Разработка проектов в области кондиционирования воздуха, холодильной техники, санитарной техники и мониторинга загрязнения окружающей среды, строительной акустики и т.п.
74.20.16	Деятельность в области промышленного и транспортного дизайна
74.20.2	Геолого-разведочные, геофизические и геохимические работы в области изучения недр и воспроизводства минерально-сырьевой базы
74.20.3	Геодезическая и картографическая деятельность
74.20.31	Топографо-геодезическая деятельность
74.20.32	Картографическая деятельность, включая деятельность в областях наименований географических объектов и создания и ведения картографо-геодезического фонда
74.20.33	Гидрографические изыскательские работы
74.20.34	Деятельность, связанная со сбором, обработкой и подготовкой картографической и космической информации, включая аэросъемку
74.20.35	Инженерные изыскания для строительства
74.20.36	Землеустройство
74.20.4	Деятельность в области стандартизации и метрологии
74.20.41	Деятельность в области стандартизации
74.20.42	Деятельность в области метрологии
74.20.44	Деятельность в области аккредитации
74.20.45	Государственный контроль и надзор за стандартами, средствами измерений и обязательной сертификацией
74.20.5	Деятельность в области гидрометеорологии и смежных с ней областях, мониторинга состояния окружающей среды, ее загрязнения
74.20.51	Деятельность наблюдательной гидрометеорологической сети
74.20.52	Проведение гелиофизических и геофизических работ
74.20.53	Деятельность по мониторингу загрязнения окружающей среды для физических и юридических лиц
74.20.54	Полевые работы и изыскания в области гидрометеорологии и смежных с ней областях, экспедиционные обследования объектов окружающей среды с целью оценки уровней загрязнения
74.20.55	Деятельность по обработке и предоставлению гидрометеорологической информации органам государственной власти и населению
74.20.56	Гидрометеорологическое обеспечение деятельности физических и юридических лиц
74.20.57	Деятельность, связанная с активными воздействиями на метеорологические и геофизические процессы и явления
74.3	Технические испытания, исследования и сертификация
74.30	Технические испытания, исследования и сертификация
74.30.1	Испытания и анализ состава и чистоты материалов и веществ: анализ химических и биологических свойств материалов и веществ (воздуха, воды, бытовых и производственных отходов, топлива, металла, почвы, химических веществ)
74.30.2	Ветеринарный контроль и контроль за производством продуктов питания
74.30.3	Испытания и анализ в научных областях (микробиологии, биохимии, бактериологии и др.)
74.30.4	Испытания и анализ физических свойств материалов и веществ: испытания и анализ физических свойств (прочности, пластичности, электропроводности, радиоактивности) материалов (металлов, пластмасс, тканей, дерева, стекла, бетона и др.); испытания на растяжение, твердость, сопротивление, усталость и высокотемпературный эффект
74.30.5	Испытания и анализ механических и электрических характеристик готовой продукции: моторов, автомобилей, станков, радиоэлектронных устройств, оборудования связи и другого оборудования, включающего механические и электрические компоненты
74.30.6	Испытания и расчеты строительных элементов
74.30.7	Технический контроль автомобилей: периодический технический осмотр легковых и грузовых автомобилей, мотоциклов, автобусов и других автотранспортных средств
74.30.8	Сертификация продукции и услуг
74.30.9	Прочая деятельность по техническому контролю, испытаниям и анализу
74.4	Рекламная деятельность
74.40	Рекламная деятельность
74.5	Трудоустройство и подбор персонала
74.50	Трудоустройство и подбор персонала
74.50.1	Предоставление услуг по трудоустройству
74.50.2	Предоставление услуг по подбору персонала
74.6	Проведение расследований и обеспечение безопасности
74.60	Проведение расследований и обеспечение безопасности
74.60.1	Оценка уязвимости объектов транспортной инфраструктуры и транспортных средств от актов незаконного вмешательства
74.60.2	Проведение расследований и обеспечение безопасности, кроме оценки уязвимости объектов транспортной инфраструктуры и транспортных средств от актов незаконного вмешательства
74.7	Чистка и уборка производственных и жилых помещений, оборудования и  транспортных средств
74.70	Чистка и уборка производственных и жилых помещений, оборудования и транспортных средств
74.70.1	Чистка и уборка производственных и жилых помещений и оборудования
74.70.2	Чистка и уборка транспортных средств
74.70.3	Деятельность по проведению дезинфекционных, дезинсекционных и дератизационных работ
74.8	Предоставление различных видов услуг
74.81	Деятельность в области фотографии
74.82	Упаковывание
74.85	Предоставление секретарских, редакторских услуг и услуг по переводу
74.86	Деятельность центров телефонного обслуживания
74.87	Предоставление прочих деловых услуг, не включенных в другие группировки
74.87.1	Взыскание платежей по счетам, оценка платежеспособности в связи с финансовым состоянием или коммерческой практикой частного лица или фирмы
74.87.2	Предоставление посреднических услуг по организации покупки и продажи мелких или средних коммерческих предприятий, включая профессиональную практику
74.87.3	Деятельность по оценке стоимости, кроме оценки, связанной с недвижимым имуществом или страхованием
74.87.4	Деятельность в области дизайна
74.87.5	Предоставление услуг по оформлению помещений, деятельность по организации ярмарок, выставок и конгрессов
74.87.6	Деятельность самостоятельных аукционистов
74.87.7	Деятельность консультантов (кроме консультантов по инженерному проектированию), не включенная в другие группировки
74.87.8	Предоставление прочих деловых услуг
	РАЗДЕЛ L ГОСУДАРСТВЕННОЕ УПРАВЛЕНИЕ И ОБЕСПЕЧЕНИЕ ВОЕННОЙ БЕЗОПАСНОСТИ; СОЦИАЛЬНОЕ СТРАХОВАНИЕ
	Подраздел LА ГОСУДАРСТВЕННОЕ УПРАВЛЕНИЕ И ОБЕСПЕЧЕНИЕ ВОЕННОЙ БЕЗОПАСНОСТИ; СОЦИАЛЬНОЕ СТРАХОВАНИЕ
75	Государственное управление и обеспечение военной безопасности; социальное страхование
75.1	Государственное управление общего и социально-экономического характера
75.11	Государственное управление общего характера
75.11.1	Деятельность федеральных органов государственной власти по управлению вопросами общего характера, кроме судебной власти
75.11.11	Деятельность федеральных органов государственной власти, кроме полномочных представителей Президента Российской Федерации и территориальных органов федеральных органов исполнительной власти
75.11.12	Деятельность полномочных представителей Президента Российской Федерации в регионах Российской Федерации и территориальных органов федеральных органов исполнительной власти в субъектах Российской Федерации (республиках, краях, областях)
75.11.13	Деятельность территориальных органов федеральных органов исполнительной власти в городах и районах субъектов Российской Федерации
75.11.2	Деятельность органов государственной власти по управлению вопросами общего характера, кроме судебной власти, субъектов Российской Федерации
75.11.21	Деятельность органов государственной власти субъектов (республик, краев, областей), кроме судебной власти, представительств субъектов Российской Федерации при Президенте Российской Федерации
75.11.22	Деятельность органов государственной власти субъектов Российской Федерации, осуществляющих свои полномочия в городах и районах
75.11.23	Деятельность органов государственной власти субъектов Российской Федерации, осуществляющих свои полномочия в сельских населенных пунктах
75.11.3	Деятельность органов местного самоуправления по управлению вопросами общего характера
75.11.31	Деятельность органов местного самоуправления муниципальных районов
75.11.32	Деятельность органов местного самоуправления городских округов
75.11.33	Деятельность органов местного самоуправления внутригородских территорий городов федерального значения
75.11.34	Деятельность органов местного самоуправления городских поселений
75.11.35	Деятельность органов местного самоуправления сельских поселений
75.11.4	Управление финансовой и фискальной деятельностью
75.11.5	Управление деятельностью в области прогнозирования и планирования
75.11.6	Управление деятельностью в области фундаментальных исследований
75.11.7	Управление деятельностью в области статистики и социологии
75.11.8	Управление имуществом, находящимся в государственной собственности
75.12	Государственное управление социальными программами
75.13	Регулирование и содействие эффективному ведению экономической деятельности, деятельность в области региональной, национальной и молодежной политики
75.14	Вспомогательная деятельность в области государственного управления
75.2	Предоставление государством услуг обществу в целом
75.21	Международная деятельность
75.22	Деятельность, связанная с обеспечением военной безопасности
75.23	Деятельность в области юстиции и правосудия
75.23.1	Деятельность Федеральных судов
75.23.11	Деятельность Конституционного суда Российской Федерации
75.23.12	Деятельность Верховного суда Российской Федерации
75.23.13	Деятельность Верховных судов субъектов Российской Федерации
75.23.14	Деятельность районных судов
75.23.15	Деятельность военных судов
75.23.16	Деятельность Высшего арбитражного суда Российской Федерации
75.23.17	Деятельность Федеральных арбитражных судов округов
75.23.18	Деятельность арбитражных судов субъектов Российской Федерации
75.23.19	Деятельность специализированных судов
75.23.2	Деятельность судов субъектов Российской Федерации
75.23.21	Деятельность конституционных (уставных) судов
75.23.22	Деятельность мировых судей
75.23.3	Деятельность органов прокуратуры Российской Федерации
75.23.31	Деятельность Генеральной прокуратуры Российской Федерации
75.23.32	Деятельность прокуратур субъектов Российской Федерации
75.23.33	Деятельность прокуратур городов и районов
75.23.4	Деятельность по управлению и эксплуатации тюрем, исправительных колоний и других мест лишения свободы, а также по оказанию реабилитационной помощи бывшим заключенным
75.23.5	Деятельность Следственного комитета Российской Федерации
75.23.51	Деятельность центрального аппарата Следственного комитета Российской Федерации
75.23.52	Деятельность Главного военного следственного управления, главных следственных управлений и следственных управлений Следственного комитета Российской Федерации по субъектам Российской Федерации (в том числе подразделений указанных управлений по административным округам) и приравненных к ним специализированных (в том числе военных) следственных управлений и следственных отделов Следственного комитета Российской Федерации
75.24	Деятельность по обеспечению общественного порядка и безопасности
75.24.1	Деятельность органов внутренних дел
75.24.2	Деятельность специализированных государственных органов охраны и безопасности
75.25	Деятельность по обеспечению безопасности в чрезвычайных ситуациях
75.25.1	Деятельность по обеспечению пожарной безопасности
75.25.2	Деятельность по обеспечению безопасности на водных объектах
75.25.3	Прочая деятельность по обеспечению безопасности в чрезвычайных ситуациях
75.3	Деятельность в области обязательного социального страхования
75.30	Деятельность в области обязательного социального страхования
	РАЗДЕЛ M   ОБРАЗОВАНИЕ
	Подраздел MА ОБРАЗОВАНИЕ
80	Образование
80.1	Дошкольное и начальное общее образование
80.10	Дошкольное и начальное общее образование
80.10.1	Дошкольное образование (предшествующее начальному общему образованию)
80.10.2	Начальное общее образование
80.10.3	Дополнительное образование детей
80.2	Основное общее, среднее (полное) общее, начальное профессиональное образование и среднее профессиональное образование
80.21	Основное общее и среднее (полное) общее образование
80.21.1	Основное общее образование
80.21.2	Среднее (полное) общее образование
80.22	Начальное и среднее профессиональное образование
80.22.1	Начальное профессиональное образование
80.22.2	Среднее профессиональное образование
80.22.21	Обучение в образовательных учреждениях среднего профессионального образования
80.22.22	Обучение в образовательных учреждениях дополнительного профессионального образования (повышения квалификации) для специалистов, имеющих среднее профессиональное образование
80.22.23	Обучение на подготовительных курсах для поступления в образовательные учреждения среднего профессионального образования
80.3	Высшее профессиональное образование
80.30	Высшее профессиональное образование
80.30.1	Обучение в образовательных учреждениях высшего профессионального образования (университетах, академиях, институтах и в др.)
80.30.2	Послевузовское профессиональное образование
80.30.3	Обучение в образовательных учреждениях дополнительного профессионального образования (повышения квалификации) для специалистов, имеющих высшее профессиональное образование
80.30.4	Обучение на подготовительных курсах для поступления в учебные заведения высшего профессионального образования
80.4	Образование для взрослых и прочие виды образования
80.41	Обучение водителей транспортных средств
80.41.1	Обучение водителей автотранспортных средств
80.41.2	Обучение летного и мореходного персонала
80.42	Образование для взрослых и прочие виды образования, не включенные в другие группировки
	РАЗДЕЛ N   ЗДРАВООХРАНЕНИЕ И ПРЕДОСТАВЛЕНИЕ СОЦИАЛЬНЫХ  УСЛУГ
	Подраздел NА ЗДРАВООХРАНЕНИЕ И ПРЕДОСТАВЛЕНИЕ СОЦИАЛЬНЫХ УСЛУГ
85	Здравоохранение и предоставление социальных услуг
85.1	Деятельность в области здравоохранения
85.11	Деятельность лечебных учреждений
85.11.1	Деятельность больничных учреждений широкого профиля и специализированных
85.11.2	Деятельность санаторно-курортных учреждений
85.12	Врачебная практика
85.13	Стоматологическая практика
85.14	Прочая деятельность по охране здоровья
85.14.1	Деятельность среднего медицинского персонала
85.14.2	Деятельность вспомогательного стоматологического персонала
85.14.3	Деятельность медицинских лабораторий
85.14.4	Деятельность учреждений скорой медицинской помощи
85.14.5	Деятельность учреждений санитарно-эпидемиологической службы
85.14.6	Деятельность судебно-медицинской экспертизы
85.2	Ветеринарная деятельность
85.20	Ветеринарная деятельность
85.20.1	Ветеринарная деятельность в сфере агропромышленного комплекса
85.20.2	Прочая ветеринарная деятельность
85.3	Предоставление социальных услуг
85.31	Предоставление социальных услуг с обеспечением проживания
85.32	Предоставление социальных услуг без обеспечения проживания
	РАЗДЕЛ O   ПРЕДОСТАВЛЕНИЕ ПРОЧИХ КОММУНАЛЬНЫХ,  СОЦИАЛЬНЫХ И ПЕРСОНАЛЬНЫХ УСЛУГ
	Подраздел OА ПРЕДОСТАВЛЕНИЕ ПРОЧИХ КОММУНАЛЬНЫХ, СОЦИАЛЬНЫХ И ПЕРСОНАЛЬНЫХ УСЛУГ
90	Сбор сточных вод, отходов и аналогичная деятельность
90.0	Сбор сточных вод, отходов и аналогичная деятельность
90.01	Сбор и обработка сточных вод
90.02	Сбор и обработка прочих отходов
90.03	Уборка территории, восстановление после загрязнения и аналогичная деятельность
91	Деятельность общественных объединений
91.1	Деятельность коммерческих, предпринимательских и профессиональных организаций
91.11	Деятельность коммерческих и предпринимательских организаций
91.12	Деятельность профессиональных организаций
91.2	Деятельность профессиональных союзов
91.20	Деятельность профессиональных союзов
91.3	Деятельность прочих общественных объединений
91.31	Деятельность религиозных организаций
91.32	Деятельность политических организаций
91.33	Деятельность прочих общественных организаций, не включенных в другие группировки
92	Деятельность по организации отдыха и развлечений, культуры и спорта
92.1	Деятельность, связанная с производством, прокатом и показом фильмов
92.11	Производство фильмов
92.12	Прокат фильмов
92.13	Показ фильмов
92.2	Деятельность в области радиовещания и телевидения
92.20	Деятельность в области радиовещания и телевидения
92.3	Прочая зрелищно-развлекательная деятельность
92.31	Деятельность в области искусства
92.31.1	Деятельность в области создания произведений искусства
92.31.2	Деятельность в области художественного, литературного и исполнительского творчества
92.31.21	Деятельность по организации и постановке театральных и оперных представлений, концертов и прочих сценических выступлений
92.31.22	Деятельность актеров, режиссеров, композиторов, художников, скульпторов и прочих представителей творческих профессий, выступающих на индивидуальной основе
92.32	Деятельность концертных и театральных залов
92.33	Деятельность ярмарок и парков с аттракционами
92.34	Прочая зрелищно-развлекательная деятельность
92.34.1	Деятельность цирков
92.34.2	Деятельность танцплощадок, дискотек, школ танцев
92.34.3	Прочая зрелищно-развлекательная деятельность, не включенная в другие группировки
92.4	Деятельность информационных агентств
92.40	Деятельность информационных агентств
92.5	Прочая деятельность в области культуры
92.51	Деятельность библиотек, архивов, учреждений клубного типа
92.52	Деятельность музеев и охрана исторических мест и зданий
92.53	Деятельность ботанических садов, зоопарков и заповедников
92.6	Деятельность в области спорта
92.61	Деятельность спортивных объектов
92.62	Прочая деятельность в области спорта
92.7	Прочая деятельность по организации отдыха и развлечений
92.71	Деятельность по организации азартных игр
92.72	Прочая деятельность по организации отдыха и развлечений, не включенная в другие группировки
93	Предоставление персональных услуг
93.0	Предоставление персональных услуг
93.01	Стирка, химическая чистка и окрашивание текстильных и меховых изделий
93.02	Предоставление услуг парикмахерскими и салонами красоты
93.03	Организация похорон и предоставление связанных с ними услуг
93.04	Физкультурно-оздоровительная деятельность
93.05	Предоставление прочих персональных услуг
	РАЗДЕЛ Р ДЕЯТЕЛЬНОСТЬ ДОМАШНИХ ХОЗЯЙСТВ
	Подраздел PА ДЕЯТЕЛЬНОСТЬ ДОМАШНИХ ХОЗЯЙСТВ
95	Деятельность домашних хозяйств с наемными работниками
95.0	Деятельность домашних хозяйств с наемными работниками
95.00	Деятельность домашних хозяйств с наемными работниками
96	Деятельность частных домашних хозяйств по производству товаров для собственного потребления
96.0	Деятельность частных домашних хозяйств по производству товаров для собственного потребления
96.00	Деятельность частных домашних хозяйств по производству товаров для собственного потребления
97	Деятельность частных домашних хозяйств по предоставлению услуг для собственного пользования
97.0	Деятельность частных домашних хозяйств по предоставлению услуг для собственного пользования
97.00	Деятельность частных домашних хозяйств по предоставлению услуг для собственного пользования
	РАЗДЕЛ Q ДЕЯТЕЛЬНОСТЬ ЭКСТЕРРИТОРИАЛЬНЫХ ОРГАНИЗАЦИЙ
	Подраздел QА ДЕЯТЕЛЬНОСТЬ ЭКСТЕРРИТОРИАЛЬНЫХ ОРГАНИЗАЦИЙ
99	Деятельность экстерриториальных организаций
99.0	Деятельность экстерриториальных организаций
99.00	Деятельность экстерриториальных организаций"""

# TODO: make okved v1

# k = [x.split('\t') for x in doc.split('\n')]
# OKVED = {int(x[0]): x[1] for x in k if ('.' not in x[0] and x[0])}

DOCv2 = """1	Растениеводство и животноводство, охота и предоставление соответствующих услуг в этих областях
2	Лесоводство и лесозаготовки
3	Рыболовство и рыбоводство
5	Добыча угля
6	Добыча сырой нефти и природного газа
7	Добыча металлических руд
8	Добыча прочих полезных ископаемых
9	Предоставление услуг в области добычи полезных ископаемых
10	Производство пищевых продуктов
11	Производство напитков
12	Производство табачных изделий
13	Производство текстильных изделий
14	Производство одежды
15	Производство кожи и изделий из кожи
16	Обработка древесины и производство изделий из дерева и пробки, кроме мебели, производство изделий из соломки и материалов для плетения
17	Производство бумаги и бумажных изделий
18	Деятельность полиграфическая и копирование носителей информации
19	Производство кокса и нефтепродуктов
20	Производство химических веществ и химических продуктов
21	Производство лекарственных средств и материалов, применяемых в медицинских целях
22	Производство резиновых и пластмассовых изделий
23	Производство прочей неметаллической минеральной продукции
24	Производство металлургическое
25	Производство готовых металлических изделий, кроме машин и оборудования
26	Производство компьютеров, электронных и оптических изделий
27	Производство электрического оборудования
28	Производство машин и оборудования, не включенных в другие группировки
29	Производство автотранспортных средств, прицепов и полуприцепов
30	Производство прочих транспортных средств и оборудования
31	Производство мебели
32	Производство прочих готовых изделий
33	Ремонт и монтаж машин и оборудования
35	Обеспечение электрической энергией, газом и паром; кондиционирование воздуха
36	Забор, очистка и распределение воды
37	Сбор и обработка сточных вод
38	Сбор, обработка и утилизация отходов; обработка вторичного сырья
39	Предоставление услуг в области ликвидации последствий загрязнений и прочих услуг, связанных с удалением отходов
41	Строительство зданий
42	Строительство инженерных сооружений
43	Работы строительные специализированные
45	Торговля оптовая и розничная автотранспортными средствами и мотоциклами и их ремонт
46	Торговля оптовая, кроме оптовой торговли автотранспортными средствами и мотоциклами
47	Торговля розничная, кроме торговли автотранспортными средствами и мотоциклами
49	Деятельность сухопутного и трубопроводного транспорта
50	Деятельность водного транспорта
51	Деятельность воздушного и космического транспорта
52	Складское хозяйство и вспомогательная транспортная деятельность
53	Деятельность почтовой связи и курьерская деятельность
55	Деятельность по предоставлению мест для временного проживания
56	Деятельность по предоставлению продуктов питания и напитков
58	Деятельность издательская
59	Производство кинофильмов, видеофильмов и телевизионных программ, издание звукозаписей и нот
60	Деятельность в области телевизионного и радиовещания
61	Деятельность в сфере телекоммуникаций
62	Разработка компьютерного программного обеспечения, консультационные услуги в данной области и другие сопутствующие услуги
63	Деятельность в области информационных технологий
64	Деятельность по предоставлению финансовых услуг, кроме услуг по страхованию и пенсионному обеспечению
65	Страхование, перестрахование, деятельность негосударственных пенсионных фондов, кроме обязательного социального обеспечения
66	Деятельность вспомогательная в сфере финансовых услуг и страхования
68	Операции с недвижимым имуществом
69	Деятельность в области права и бухгалтерского учета
70	Деятельность головных офисов; консультирование по вопросам управления
71	Деятельность в области архитектуры и инженерно-технического проектирования; технических испытаний, исследований и анализа
72	Научные исследования и разработки
73	Деятельность рекламная и исследование конъюнктуры рынка
74	Деятельность профессиональная научная и техническая прочая
75	Деятельность ветеринарная
77	Аренда и лизинг
78	Деятельность по трудоустройству и подбору персонала
79	Деятельность туристических агентств и прочих организаций, предоставляющих услуги в сфере туризма
80	Деятельность по обеспечению безопасности и проведению расследований
81	Деятельность по обслуживанию зданий и территорий
82	Деятельность административно-хозяйственная, вспомогательная деятельность по обеспечению функционирования организации, деятельность по предоставлению прочих вспомогательных услуг для бизнеса
84	Деятельность органов государственного управления по обеспечению военной безопасности, обязательному социальному обеспечению
85	Образование
86	Деятельность в области здравоохранения
87	Деятельность по уходу с обеспечением проживания
88	Предоставление социальных услуг без обеспечения проживания
90	Деятельность творческая, деятельность в области искусства и организации развлечений
91	Деятельность библиотек, архивов, музеев и прочих объектов культуры
92	Деятельность по организации и проведению азартных игр и заключению пари, по организации и проведению лотерей
93	Деятельность в области спорта, отдыха и развлечений
94	Деятельность общественных организаций
95	Ремонт компьютеров, предметов личного потребления и хозяйственно-бытового назначения
96	Деятельность по предоставлению прочих персональных услуг
97	Деятельность домашних хозяйств с наемными работниками
98	Деятельность недифференцированная частных домашних хозяйств по производству товаров и предоставлению услуг для собственного потребления
99	Деятельность экстерриториальных организаций и органов"""


def split_to_dict(doc: str = DOCv2) -> dict:
    result = {}
    for line in doc.split("\n"):
        a, b = line.split("\t")
        d = {int(a): b}
        result.update(d)
    return result


OKVEDv2 = split_to_dict()


def all_codes_v2():
    return [x for x in OKVEDv2.keys()]


def name_v2(code: int) -> str:
    try:
        return OKVEDv2[code]
    except KeyError:
        raise ValueError(
            f"Cannot process code {code}. " f"Industry code must be in {all_codes_v2()}"
        )
